@@ -48,6 +48,6 @@ public:
 	void setText(const FXString&);
     void SelectAll();
     void CursorEnd();
-  	FXbool setSelection(FXint, FXint);
+  	void setSelection(int, int);
 };
 #endif
