@@ -16,6 +16,7 @@
 #include <sys/ioctl.h>
 #include <unistd.h>
 #include <fcntl.h>
+#include <errno.h>
 
 #include <fx.h>
 
@@ -140,7 +141,7 @@ long CommandWindow::onUpdClose(FXObject* sender,FXSelector,void*)
 
 // Execute a command and capture its output
 int CommandWindow::execCmd(FXString command)
-{
+{	
     // Open pipes to communicate with child process
     if (pipe(pipes)==-1)
         return -1;
@@ -157,9 +158,21 @@ int CommandWindow::execCmd(FXString command)
         ::close(0);
         ::close(1);
         ::close(2);                   // Close stdin, stdout and stderr and
-        dup(pipes[0]);                // use the pipes as the new channels
-        dup(pipes[1]);                // (where stdout and stderr
-        dup(pipes[1]);                // go to the same pipe!).
+        int ret1=dup(pipes[0]);       // use the pipes as the new channels
+        int ret2=dup(pipes[1]);       // (where stdout and stderr
+        int ret3=dup(pipes[1]);       // go to the same pipe!).
+
+		if (ret1 < 0 || ret2 < 0 || ret3 < 0)
+		{
+			int errcode=errno;	
+			if (errcode)
+				MessageBox::error(this,BOX_OK,_("Error"),_("Can't duplicate pipes: %s"),strerror(errcode));
+			else
+				MessageBox::error(this,BOX_OK,_("Error"),_("Can't duplicate pipes"));
+			
+			return -1;
+		}			 
+ 
         ::close(pipes[0]);            // Close the child's
         ::close(pipes[1]);            // pipes.
         args[0] = (char*)"sh";               // Setup arguments
@@ -173,7 +186,7 @@ int CommandWindow::execCmd(FXString command)
     {
         // Here, we are running as the parent process!
         // Make sure we get called so we can check when child has finished
-         getApp()->addChore(this,ID_WATCHPROCESS);
+        getApp()->addChore(this,ID_WATCHPROCESS);
    }
     return 0;
 }
