@@ -31,10 +31,10 @@ FXIMPLEMENT(DirHistBox,DialogBox,DirHistBoxMap,ARRAYNUMBER(DirHistBoxMap))
 
 
 // Construct list box with given caption, icon, message text, and with choices from array of strings
-DirHistBox::DirHistBox(FXWindow* owner,const FXchar** choices,FXuint opts,FXint x,FXint y,FXint w,FXint h):
+DirHistBox::DirHistBox(FXWindow* owner,const char** choices,unsigned int opts,int x,int y,int w,int h):
         DialogBox(owner,"",opts,x,y,w,h,0,0,0,0, 0,0)
 {
-    register FXint n;
+    register int n;
 	FXHorizontalFrame* hor=new FXHorizontalFrame(this,FRAME_RAISED|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 0,0,0,0, 0,0);
     list=new FXList(hor,this,ID_CLICKED,LIST_BROWSESELECT|LAYOUT_FILL_Y|LAYOUT_FILL_X|HSCROLLING_OFF);
 	list->setBackColor(this->getBackColor());
@@ -44,10 +44,10 @@ DirHistBox::DirHistBox(FXWindow* owner,const FXchar** choices,FXuint opts,FXint
 
 
 // Construct list box with given caption, icon, message text, and with choices from newline separated strings
-DirHistBox::DirHistBox(FXWindow* owner,const FXString& choices,FXuint opts,FXint x,FXint y,FXint w,FXint h):
+DirHistBox::DirHistBox(FXWindow* owner,const FXString& choices,unsigned int opts,int x,int y,int w,int h):
         DialogBox(owner,"",opts,x,y,w,h,0,0,0,0, 0,0)
 {
-    register FXint n;
+    register int n;
 	FXHorizontalFrame* hor=new FXHorizontalFrame(this,FRAME_RAISED|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 0,0,0,0, 0,0);
     list=new FXList(hor,this,ID_CLICKED,LIST_BROWSESELECT|LAYOUT_FILL_Y|LAYOUT_FILL_X|HSCROLLING_OFF);
 	list->setBackColor(this->getBackColor());
@@ -81,7 +81,7 @@ DirHistBox::~DirHistBox()
 
 
 // Show a modal list dialog
-FXint DirHistBox::box(FXWindow* owner,FXuint opts,const FXchar** choices,FXint x,FXint y,FXint w,FXint h)
+int DirHistBox::box(FXWindow* owner,unsigned int opts,const char** choices,int x,int y,int w,int h)
 {
     DirHistBox box(owner,choices,opts,x,y,w,h);
     return box.execute(PLACEMENT_DEFAULT);
@@ -89,7 +89,7 @@ FXint DirHistBox::box(FXWindow* owner,FXuint opts,const FXchar** choices,FXint x
 
 
 // Show a modal list dialog
-FXint DirHistBox::box(FXWindow* owner,FXuint opts,const FXString& choices,FXint x,FXint y,FXint w,FXint h)
+int DirHistBox::box(FXWindow* owner,unsigned int opts,const FXString& choices,int x,int y,int w,int h)
 {
     DirHistBox box(owner,choices,opts,x,y,w,h);
     return box.execute(PLACEMENT_DEFAULT);
