@@ -1108,11 +1108,11 @@ long DirList::onMtdevicesRefresh(FXObject*,FXSelector,void*)
 
 	// Remove mount points that don't exist anymore
 	int s;
-	const char *key, *data;
+	//const char *key, *data;
 	for (s = mtdevices->first(); s < mtdevices->size(); s = mtdevices->next(s))
 	{
-		key = mtdevices->key(s);
-		data = mtdevices->data(s);
+		//key = mtdevices->key(s);
+		//data = mtdevices->data(s);
 		if (!tmpdict->find(mtdevices->key(s)))
 			mtdevices->remove(mtdevices->key(s));
 	}
@@ -1170,11 +1170,11 @@ long DirList::onUpdevicesRefresh(FXObject*,FXSelector,void*)
 
     // Remove mount points that don't exist anymore
     int s;
-    const char *key, *data;
+    //const char *key, *data;
     for (s = updevices->first(); s < updevices->size(); s = updevices->next(s))
     {
-        key = updevices->key(s);
-        data = updevices->data(s);
+        //key = updevices->key(s);
+        //data = updevices->data(s);
         if (!tmpdict->find(updevices->key(s)))
             updevices->remove(updevices->key(s));
 
@@ -1954,8 +1954,10 @@ long DirList::onUpdRefreshTimers(FXObject*,FXSelector,void*)
 	if (prevMinimized == FALSE && minimized == TRUE)
 	{
 		onCmdRefreshTimer(0,0,0);
+#if defined(linux)
 		onMtdevicesRefresh(0,0,0);
 		onUpdevicesRefresh(0,0,0);
+#endif
 	}
 
     return 1;
