@@ -779,6 +779,7 @@ long DirPanel::onCmdProperties(FXObject* sender, FXSelector, void*)
 // Add files or directory to an archive
 long DirPanel::onCmdAddToArch(FXObject* o,FXSelector,void*)
 {
+	int ret;
 	FXString ext1, ext2, cmd, archive;
 	File *f;
 
@@ -791,7 +792,17 @@ long DirPanel::onCmdAddToArch(FXObject* o,FXSelector,void*)
     // Initial archive name with full path and default extension
     archive=parentdir+PATHSEPSTRING+name+".tar.gz";
 
-	chdir(parentdir.text());
+	ret=chdir(parentdir.text());
+	if (ret < 0)
+	{
+		int errcode=errno;	
+		if (errcode)
+			MessageBox::error(this,BOX_OK,_("Error"),_("Can't enter folder %s: %s"),parentdir.text(),strerror(errcode));
+		else
+			MessageBox::error(this,BOX_OK,_("Error"),_("Can't enter folder %s"),parentdir.text());
+		
+		return 0;
+	}
 
 	// Archive dialog
 	if (archdialog==NULL)
@@ -867,7 +878,17 @@ long DirPanel::onCmdAddToArch(FXObject* o,FXSelector,void*)
 
 		// Create archive
 		f->archive(archive,cmd);
-		chdir(startlocation.text());
+		ret=chdir(startlocation.text());
+		if (ret < 0)
+		{
+			int errcode=errno;	
+			if (errcode)
+				MessageBox::error(this,BOX_OK,_("Error"),_("Can't enter folder %s: %s"),startlocation.text(),strerror(errcode));
+			else
+				MessageBox::error(this,BOX_OK,_("Error"),_("Can't enter folder %s"),startlocation.text());
+			
+			return 0;
+		}
  
 		getApp()->endWaitCursor();
 		delete f; 
@@ -1326,7 +1347,8 @@ long DirPanel::onCmdDirMan(FXObject* sender,FXSelector sel,void* ptr)
         {
             message=_("Copy ");
             message+=source;
-            target+=name;
+			if (::isFile(source))
+            	target+=name;
 		}
         else
 			message.format(_("Copy %s items from: %s"),FXStringVal(num).text(),dir.text());
@@ -1382,7 +1404,8 @@ long DirPanel::onCmdDirMan(FXObject* sender,FXSelector sel,void* ptr)
         {
             message=_("Move ");
             message+=source;
-            target+=name;
+			if (::isFile(source))
+            	target+=name;
             title=_("Move");
         }
         else
@@ -2099,7 +2122,7 @@ long DirPanel::onCmdDirRestore(FXObject*,FXSelector,void*)
 			// Ask the user if he wants to create it
 			f->hideProgressDialog();
 			FXString message;
-			message.format(_("Parent directory %s does not exist, do you want to create it?"),origparentdir.text());
+			message.format(_("Parent folder %s does not exist, do you want to create it?"),origparentdir.text());
 			MessageBox box(this,_("Confirm Restore"),message,restore_bigicon,BOX_OK_CANCEL|DECOR_TITLE|DECOR_BORDER);
 			if(box.execute(PLACEMENT_CURSOR) != BOX_CLICKED_OK)
 				goto end;
@@ -2208,14 +2231,45 @@ long DirPanel::onCmdNewDir(FXObject*,FXSelector,void*)
 // Run Terminal in the selected directory
 long DirPanel::onCmdXTerm(FXObject*,FXSelector,void*)
 {
+	int ret;
+	
 	getApp()->beginWaitCursor();
     DirItem* item=(DirItem*)list->getCurrentItem();
 	FXString buf=list->getItemPathname((TreeItem*)item);
-	chdir(buf.text());
+	ret=chdir(buf.text());
+	if (ret < 0)
+	{
+		int errcode=errno;	
+		if (errcode)
+			MessageBox::error(this,BOX_OK,_("Error"),_("Can't enter folder %s: %s"),buf.text(),strerror(errcode));
+		else
+			MessageBox::error(this,BOX_OK,_("Error"),_("Can't enter folder %s"),buf.text());
+		
+		return 0;
+	}
+
     FXString cmd=getApp()->reg().readStringEntry("PROGS","xterm","xterm -sb");
     cmd += " &";
-    system(cmd.text());
-	chdir(startlocation.text());
+
+    ret=system(cmd.text());
+	if (ret < 0)
+	{
+		MessageBox::error(this,BOX_OK,_("Error"),_("Can't execute command %s"),cmd.text());
+		return 0;
+	}
+
+	ret=chdir(startlocation.text());
+	if (ret < 0)
+	{
+		int errcode=errno;	
+		if (errcode)
+			MessageBox::error(this,BOX_OK,_("Error"),_("Can't enter folder %s: %s"),startlocation.text(),strerror(errcode));
+		else
+			MessageBox::error(this,BOX_OK,_("Error"),_("Can't enter folder %s"),startlocation.text());
+		
+		return 0;
+	}
+
 	getApp()->endWaitCursor();
     return 1;
 }
@@ -2225,6 +2279,7 @@ long DirPanel::onCmdXTerm(FXObject*,FXSelector,void*)
 // Mount/Unmount directory
 long DirPanel::onCmdMount(FXObject*,FXSelector sel,void*)
 {
+	int ret;
     FXString cmd, msg, text;
 	unsigned int op;
 	File *f;
@@ -2252,7 +2307,17 @@ long DirPanel::onCmdMount(FXObject*,FXSelector sel,void*)
     }
     cmd+=::quote(dir);
     cmd+=" 2>&1";
-    chdir(ROOTDIR);
+    ret=chdir(ROOTDIR);
+	if (ret < 0)
+	{
+		int errcode=errno;	
+		if (errcode)
+			MessageBox::error(this,BOX_OK,_("Error"),_("Can't enter folder %s: %s"),ROOTDIR,strerror(errcode));
+		else
+			MessageBox::error(this,BOX_OK,_("Error"),_("Can't enter folder %s"),ROOTDIR);
+		
+		return 0;
+	}
 
 	// Wait cursor
 	getApp()->beginWaitCursor();
@@ -2265,8 +2330,18 @@ long DirPanel::onCmdMount(FXObject*,FXSelector sel,void*)
 	// Mount/unmount file system
 	text=msg + _(" the folder:");
 	f->mount(dir,text,cmd,op);
-	chdir(startlocation.text());
- 
+	ret=chdir(startlocation.text());
+ 	if (ret < 0)
+	{
+		int errcode=errno;	
+		if (errcode)
+			MessageBox::error(this,BOX_OK,_("Error"),_("Can't enter folder %s: %s"),startlocation.text(),strerror(errcode));
+		else
+			MessageBox::error(this,BOX_OK,_("Error"),_("Can't enter folder %s"),startlocation.text());
+		
+		return 0;
+	}
+	
 	// If action is cancelled in progress dialog
 	if (f->isCancelled())
 	{
@@ -2496,7 +2571,7 @@ long DirPanel::onCmdDirsizeRefresh(FXObject* sender,FXSelector,void*)
 	if (!allowDirsizeRefresh || ((FXTopWindow*)focuswindow)->isMinimized())
 		return 0;
 
-	FXulong dnsize;
+	unsigned long long dnsize;
 	char dsize[64];
 	FXString hsize;
 		
