@@ -263,7 +263,7 @@ unsigned int File::getOverwriteAnswer(FXString srcpath, FXString tgtpath)
 	// Message string
 	FXString msg;
 	if (::isDirectory(tgtpath))
-		msg.format(_("Folder %s already exists. Overwrite?\n=> Caution, all files within this directory will be definitively lost!"),tgtpath.text());
+		msg.format(_("Folder %s already exists. Overwrite?\n=> Caution, all files within this folder will be definitively lost!"),tgtpath.text());
 	else
 		msg.format(_("File %s already exists. Overwrite?"),tgtpath.text());
 
@@ -281,14 +281,14 @@ unsigned int File::getOverwriteAnswer(FXString srcpath, FXString tgtpath)
 		char buf[MAXPATHLEN];
 		if (S_ISDIR(linfo.st_mode)) // Folder
 		{
-			FXulong dirsize=0;
+			unsigned long long dirsize=0;
 			unsigned int nbfiles=0, nbsubfolders=0;
 			strlcpy(buf,srcpath.text(),srcpath.length()+1);
 			dirsize=pathsize(buf,&nbfiles,&nbsubfolders);
 			snprintf(buf,sizeof(buf),"%llu",dirsize);
 		}
 		else // File
-			snprintf(buf,sizeof(buf),"%llu",(FXulong)linfo.st_size);					
+			snprintf(buf,sizeof(buf),"%llu",(unsigned long long)linfo.st_size);					
 		srcsize=::hSize(buf);
 	}			
 	if (lstatrep(tgtpath.text(),&linfo)==0)
@@ -298,14 +298,14 @@ unsigned int File::getOverwriteAnswer(FXString srcpath, FXString tgtpath)
 		char buf[64];
 		if (S_ISDIR(linfo.st_mode)) // Folder
 		{
-			FXulong dirsize=0;
+			unsigned long long dirsize=0;
 			unsigned int nbfiles=0, nbsubfolders=0;
 			strlcpy(buf,tgtpath.text(),tgtpath.length()+1);
 			dirsize=pathsize(buf,&nbfiles,&nbsubfolders);
 			snprintf(buf,sizeof(buf),"%llu",dirsize);
 		}
 		else // File
-			snprintf(buf,sizeof(buf),"%llu",(FXulong)linfo.st_size);					
+			snprintf(buf,sizeof(buf),"%llu",(unsigned long long)linfo.st_size);					
 		tgtsize=::hSize(buf);
 	}			
 	
@@ -719,6 +719,15 @@ int File::copy(const FXString& source, const FXString& target, const FXbool conf
 		return -1;
 	}
 
+	// Source path is included into target path
+	FXString str=source + PATHSEPSTRING;
+	if (target.left(str.length()) == str)
+	{
+		forceTimeout();
+		MessageBox::error(this,BOX_OK,_("Error"),_("Target %s is a sub-folder of source"),target.text());
+		return -1;
+	}
+
 	// Target is an existing directory
 	if (::isDirectory(target))
 		targetfile=target+PATHSEPSTRING+FXPath::name(source);
@@ -1042,7 +1051,6 @@ int File::move(const FXString& source,const FXString& target,const FXbool restor
 		forceTimeout();
 		MessageBox::error(this,BOX_OK,_("Error"),_("Target %s is a sub-folder of source"),target.text());
 		return -1;
-		
 	}
 
 	// Target is an existing directory (don't do this in the restore case)
@@ -1558,9 +1566,21 @@ int File::rchown(char* path, char* file, uid_t uid, gid_t gid, const FXbool diro
 // Extract an archive in a specified directory
 int File::extract(const FXString name, const FXString dir, const FXString cmd)
 {
+	int ret;
+	
 	// Change to the specified directory
     FXString currentdir=FXSystem::getCurrentDirectory();
-	chdir(dir.text());
+	ret=chdir(dir.text());
+	if (ret < 0)
+	{
+		int errcode=errno;	
+		if (errcode)
+			MessageBox::error(this,BOX_OK,_("Error"),_("Can't enter folder %s: %s"),dir.text(),strerror(errcode));
+		else
+			MessageBox::error(this,BOX_OK,_("Error"),_("Can't enter folder %s"),dir.text());
+		
+		return 0;
+	}
 
     // Make and show command window
 	CommandWindow *cmdwin=new CommandWindow(getApp(),_("Extract archive"),cmd,30,80);			
@@ -1570,7 +1590,17 @@ int File::extract(const FXString name, const FXString dir, const FXString cmd)
 	// The command window object deletes itself after closing the window!
 
 	// Return to initial directory
-	chdir(currentdir.text());
+	ret=chdir(currentdir.text());
+	if (ret < 0)
+	{
+		int errcode=errno;	
+		if (errcode)
+			MessageBox::error(this,BOX_OK,_("Error"),_("Can't enter folder %s: %s"),currentdir.text(),strerror(errcode));
+		else
+			MessageBox::error(this,BOX_OK,_("Error"),_("Can't enter folder %s"),currentdir.text());
+		
+		return 0;
+	}
 	
     return 1;
 }
