@@ -129,30 +129,30 @@ FileSelector::FileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,unsigned
 	new FXFrame(buttons,LAYOUT_FIX_WIDTH,0,0,4,1);
 
 	key=getApp()->reg().readStringEntry("KEYBINDINGS","go_back","Ctrl-Backspace");
-    btn=new FXButton(buttons,TAB+_("Go to previous directory")+PARS(key),dirbackicon,this,ID_DIR_BACK,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
+    btn=new FXButton(buttons,TAB+_("Go to previous folder")+PARS(key),dirbackicon,this,ID_DIR_BACK,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
 	hotkey=_parseAccel(key);
 	btn->addHotKey(hotkey);
 
 	btnbackhist=new FXArrowButton(buttons,this,ID_DIR_BACK_HIST,LAYOUT_FILL_Y|FRAME_RAISED|FRAME_THICK|ARROW_DOWN|ARROW_TOOLBAR);
 
 	key=getApp()->reg().readStringEntry("KEYBINDINGS","go_forward","Shift-Backspace");
-    btn=new FXButton(buttons,TAB+_("Go to next directory")+PARS(key),dirforwardicon,this,ID_DIR_FORWARD,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
+    btn=new FXButton(buttons,TAB+_("Go to next folder")+PARS(key),dirforwardicon,this,ID_DIR_FORWARD,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
 	hotkey=_parseAccel(key);
 	btn->addHotKey(hotkey);
 
 	btnforwardhist=new FXArrowButton(buttons,this,ID_DIR_FORWARD_HIST,LAYOUT_FILL_Y|FRAME_RAISED|FRAME_THICK|ARROW_DOWN|ARROW_TOOLBAR);
 	key=getApp()->reg().readStringEntry("KEYBINDINGS","go_up","Backspace");
-    btn=new FXButton(buttons,TAB+_("Go to parent directory")+PARS(key),dirupicon,this,ID_DIR_UP,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
+    btn=new FXButton(buttons,TAB+_("Go to parent folder")+PARS(key),dirupicon,this,ID_DIR_UP,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
 	hotkey=_parseAccel(key);
 	btn->addHotKey(hotkey);
 
  	key=getApp()->reg().readStringEntry("KEYBINDINGS","go_home","Ctrl-H");
-    btn=new FXButton(buttons,TAB+_("Go to home directory")+PARS(key),homeicon,this,ID_HOME,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
+    btn=new FXButton(buttons,TAB+_("Go to home folder")+PARS(key),homeicon,this,ID_HOME,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
 	hotkey=_parseAccel(key);
 	btn->addHotKey(hotkey);
 
  	key=getApp()->reg().readStringEntry("KEYBINDINGS","go_work","Shift-F2");
-    btn=new FXButton(buttons,TAB+_("Go to working directory")+PARS(key),workicon,this,ID_WORK,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
+    btn=new FXButton(buttons,TAB+_("Go to working folder")+PARS(key),workicon,this,ID_WORK,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
 	hotkey=_parseAccel(key);
 	btn->addHotKey(hotkey);
 
@@ -211,7 +211,7 @@ FileSelector::FileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,unsigned
 		hotkey=_parseAccel(key);	
 		table->addAccel(hotkey,list,FXSEL(SEL_COMMAND,FileList::ID_SELECT_INVERSE));
 	
-		key=getApp()->reg().readStringEntry("KEYBINDINGS","new_file","F2");
+		key=getApp()->reg().readStringEntry("KEYBINDINGS","new_file","Ctrl-N");
 		hotkey=_parseAccel(key);	
 		table->addAccel(hotkey,this,FXSEL(SEL_COMMAND,ID_NEWFILE));
     }
@@ -1431,7 +1431,7 @@ long FileSelector::onCmdPopupMenu(FXObject* o,FXSelector s,void* p)
 	new FXMenuRadio(&menu,_("&Permissions"),list,FileList::ID_SORT_BY_PERM);
 	new FXMenuSeparator(&menu);
 	new FXMenuCheck(&menu,_("Ignore c&ase"),list,FileList::ID_SORT_CASE);
-	new FXMenuCheck(&menu,_("Dir&ectories first"),list,FileList::ID_DIRS_FIRST);
+	new FXMenuCheck(&menu,_("Fold&ers first"),list,FileList::ID_DIRS_FIRST);
 	new FXMenuCheck(&menu,_("Re&verse order"),list,FileList::ID_SORT_REVERSE);
 
 	menu.create();
