@@ -15,7 +15,7 @@ struct FileAssoc
     FXIcon    *miniicon;          // Mini normal icon
     FXIcon    *miniiconopen;      // Mini open icon
     FXDragType dragtype;          // Registered drag type
-    FXuint     flags;             // Flags
+    unsigned int     flags;             // Flags
 };
 
 
@@ -39,7 +39,7 @@ private:
 public:
 
   // Default icon search path
-	static const FXchar defaultIconPath[];
+	static const char defaultIconPath[];
 
 public:
 
@@ -77,21 +77,21 @@ public:
     }
 
     // Insert unique icon loaded from filename into dictionary
-    FXIcon* insert(const FXchar* name)
+    FXIcon* insert(const char* name)
     {
         return (FXIcon*)FXDict::insert(name,name);
     }
 
     // Remove icon from dictionary
     FXIcon* remove
-        (const FXchar* name)
+        (const char* name)
     {
         return (FXIcon*)FXDict::remove
                    (name);
     }
 
     // Find icon by name
-    FXIcon* find(const FXchar* name)
+    FXIcon* find(const char* name)
     {
         return (FXIcon*)FXDict::find(name);
     }
@@ -132,13 +132,13 @@ private:
 public:
 
     // Registry key used to find fallback executable icons
-    static const FXchar defaultExecBinding[];
+    static const char defaultExecBinding[];
 
     // Registry key used to find fallback directory icons
-    static const FXchar defaultDirBinding[];
+    static const char defaultDirBinding[];
 
     // Registry key used to find fallback document icons
-    static const FXchar defaultFileBinding[];
+    static const char defaultFileBinding[];
 public:
 
     /*
@@ -198,19 +198,19 @@ public:
     * /home/jeroen=";Home;home.xpm;minihome.xpm;application/x-folder"
     *
     */
-    FileAssoc* replace(const FXchar* ext,const FXchar* str);
+    FileAssoc* replace(const char* ext,const char* str);
 
     // Remove file association
-    FileAssoc* remove (const FXchar* ext);
+    FileAssoc* remove (const char* ext);
 
     // Find file association already in dictionary
-    FileAssoc* find(const FXchar* ext)
+    FileAssoc* find(const char* ext)
     {
         return (FileAssoc*)FXDict::find(ext);
     }
 
     // Find file association from registry
-    FileAssoc* associate(const FXchar* key);
+    FileAssoc* associate(const char* key);
 
     /*
     * Determine binding for the given file.
@@ -226,7 +226,7 @@ public:
     * key "defaultfilebinding" is tried as a fallback association.
     * A NULL is returned if no association of any kind is found.
     */
-    virtual FileAssoc* findFileBinding(const FXchar* pathname);
+    virtual FileAssoc* findFileBinding(const char* pathname);
 
     /*
     * Find directory binding from registry.
@@ -242,7 +242,7 @@ public:
     * key "defaultdirbinding" is tried as a fallback association.
     * A NULL is returned if no association of any kind is found.
     */
-    virtual FileAssoc* findDirBinding(const FXchar* pathname);
+    virtual FileAssoc* findDirBinding(const char* pathname);
 
     /*
     * Determine binding for the given executable.
@@ -250,7 +250,7 @@ public:
     * the key "defaultexecbinding".
     * A NULL is returned if no association of any kind is found.
     */
-    virtual FileAssoc* findExecBinding(const FXchar* pathname);
+    virtual FileAssoc* findExecBinding(const char* pathname);
 
     // Destructor
     virtual ~FileDict();
