@@ -76,6 +76,7 @@ FilePanel(FXWindow *owner, const char*,FXComposite*, DirPanel*, unsigned int nam
 	void showCorner(FXbool show);
 	void showActiveIcon(FXbool show);
 	void execFile(FXString pathname);
+	int readScriptDir(FXMenuPane* scriptsmenu, FXString dir);
 
 	enum
 	{
@@ -98,6 +99,8 @@ FilePanel(FXWindow *owner, const char*,FXComposite*, DirPanel*, unsigned int nam
 		ID_POPUP_MENU,
 		ID_XTERM,
         ID_EXTRACT,
+        ID_RUN_SCRIPT,
+		ID_GO_SCRIPTDIR,
 		ID_EXTRACT_TO_FOLDER,
         ID_EXTRACT_HERE,
         ID_NEW_DIR,
@@ -173,6 +176,7 @@ public:
     long onCmdToggleHidden(FXObject*,FXSelector,void*);
     long onUpdToggleHidden(FXObject*,FXSelector,void*);
 	long onCmdToggleThumbnails(FXObject*,FXSelector,void*);
+	long onCmdRunScript(FXObject* o,FXSelector sel,void*);
 	long onUpdToggleThumbnails(FXObject*,FXSelector,void*);
     long onCmdAddToArch(FXObject*,FXSelector,void*);
 	long onUpdMenu(FXObject*,FXSelector,void*);
@@ -185,6 +189,8 @@ public:
 	long onUpdGoTrash(FXObject*,FXSelector,void*);
 	void updatePath();
 	long onCmdStopListRefreshTimer(FXObject*,FXSelector,void*);
+	long onUpdRunScript(FXObject*,FXSelector,void*);
+	long onCmdGoScriptDir(FXObject*, FXSelector, void*);
 
 #if defined(linux)
     long onCmdMount(FXObject*,FXSelector,void*);
@@ -517,6 +523,5 @@ public:
 	{
 		return list->forwardhist->getItemAtPos(pos);
 	}
-
 };
 #endif
