@@ -33,7 +33,7 @@ FXDEFMAP(FontSelector) FontSelectorMap[]=
 FXIMPLEMENT(FontSelector,FXPacker,FontSelectorMap,ARRAYNUMBER(FontSelectorMap))
 
 
-FontSelector::FontSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint opts,FXint x,FXint y,FXint w,FXint h):
+FontSelector::FontSelector(FXComposite *p,FXObject* tgt,FXSelector sel,unsigned int opts,int x,int y,int w,int h):
         FXPacker(p,opts,x,y,w,h)
 {
     target=tgt;
@@ -175,8 +175,8 @@ void FontSelector::create()
 void FontSelector::listFontFaces()
 {
     FXFontDesc *fonts;
-    FXuint numfonts,f;
-    FXint selindex=-1;
+    unsigned int numfonts,f;
+    int selindex=-1;
     familylist->clearItems();
     family->setText("");
     if(FXFont::listFonts(fonts,numfonts,FXString::null,0,0,selected.setwidth,selected.encoding,selected.flags))
@@ -204,9 +204,9 @@ void FontSelector::listFontFaces()
 void FontSelector::listWeights()
 {
     FXFontDesc *fonts;
-    FXuint numfonts,f,ww,lastww;
-    const FXchar *wgt;
-    FXint selindex=-1;
+    unsigned int numfonts,f,ww,lastww;
+    const char *wgt;
+    int selindex=-1;
     weightlist->clearItems();
     weight->setText("");
     if(FXFont::listFonts(fonts,numfonts,selected.face,0,0,selected.setwidth,selected.encoding,selected.flags))
@@ -268,7 +268,7 @@ void FontSelector::listWeights()
             weightlist->setCurrentItem(selindex);
             weightlist->makeItemVisible(selindex);
             weight->setText(weightlist->getItemText(selindex));
-            selected.weight=(FXuint)(FXuval)weightlist->getItemData(selindex);
+            selected.weight=(unsigned int)(FXuval)weightlist->getItemData(selindex);
         }
         FXFREE(&fonts);
     }
@@ -279,9 +279,9 @@ void FontSelector::listWeights()
 void FontSelector::listSlants()
 {
     FXFontDesc *fonts;
-    FXuint numfonts,f,s,lasts;
-    const FXchar *slt;
-    FXint selindex=-1;
+    unsigned int numfonts,f,s,lasts;
+    const char *slt;
+    int selindex=-1;
     stylelist->clearItems();
     style->setText("");
     if(FXFont::listFonts(fonts,numfonts,selected.face,selected.weight,0,selected.setwidth,selected.encoding,selected.flags))
@@ -331,7 +331,7 @@ void FontSelector::listSlants()
             stylelist->setCurrentItem(selindex);
             stylelist->makeItemVisible(selindex);
             style->setText(stylelist->getItemText(selindex));
-            selected.slant=(FXuint)(FXuval)stylelist->getItemData(selindex);
+            selected.slant=(unsigned int)(FXuval)stylelist->getItemData(selindex);
         }
         FXFREE(&fonts);
     }
@@ -341,13 +341,13 @@ void FontSelector::listSlants()
 // Fill the list with font sizes
 void FontSelector::listFontSizes()
 {
-    const FXuint sizeint[]=
+    const unsigned int sizeint[]=
         {
             60,80,90,100,110,120,140,160,200,240,300,360,420,480,640
         };
     FXFontDesc *fonts;
-    FXuint numfonts,f,s,lasts;
-    FXint selindex=-1;
+    unsigned int numfonts,f,s,lasts;
+    int selindex=-1;
     sizelist->clearItems();
     size->setText("");
     FXString string;
@@ -386,7 +386,7 @@ void FontSelector::listFontSizes()
             sizelist->setCurrentItem(selindex);
             sizelist->makeItemVisible(selindex);
             size->setText(sizelist->getItemText(selindex));
-            selected.size=(FXuint)(FXuval)sizelist->getItemData(selindex);
+            selected.size=(unsigned int)(FXuval)sizelist->getItemData(selindex);
         }
         FXFREE(&fonts);
     }
@@ -418,7 +418,7 @@ void FontSelector::previewFont()
 // Selected font family
 long FontSelector::onCmdFamily(FXObject*,FXSelector,void* ptr)
 {
-    strncpy(selected.face,familylist->getItemText((FXint)(FXival)ptr).text(),sizeof(selected.face));
+    strncpy(selected.face,familylist->getItemText((int)(FXival)ptr).text(),sizeof(selected.face));
     family->setText(selected.face);
     listWeights();
     listSlants();
@@ -431,8 +431,8 @@ long FontSelector::onCmdFamily(FXObject*,FXSelector,void* ptr)
 // Changed weight setting
 long FontSelector::onCmdWeight(FXObject*,FXSelector,void* ptr)
 {
-    selected.weight=(FXuint)(FXuval)weightlist->getItemData((FXint)(FXival)ptr);
-    weight->setText(weightlist->getItemText((FXint)(FXival)ptr));
+    selected.weight=(unsigned int)(FXuval)weightlist->getItemData((int)(FXival)ptr);
+    weight->setText(weightlist->getItemText((int)(FXival)ptr));
     listSlants();
     listFontSizes();
     previewFont();
@@ -443,8 +443,8 @@ long FontSelector::onCmdWeight(FXObject*,FXSelector,void* ptr)
 // User clicked up directory button
 long FontSelector::onCmdSize(FXObject*,FXSelector,void* ptr)
 {
-    selected.size=(FXuint)(FXuval)sizelist->getItemData((FXint)(FXival)ptr);
-    size->setText(sizelist->getItemText((FXint)(FXival)ptr));
+    selected.size=(unsigned int)(FXuval)sizelist->getItemData((int)(FXival)ptr);
+    size->setText(sizelist->getItemText((int)(FXival)ptr));
     previewFont();
     return 1;
 }
@@ -453,7 +453,7 @@ long FontSelector::onCmdSize(FXObject*,FXSelector,void* ptr)
 // User clicked up directory button
 long FontSelector::onCmdSizeText(FXObject*,FXSelector,void*)
 {
-    selected.size=(FXuint)(10.0*FXFloatVal(size->getText()));
+    selected.size=(unsigned int)(10.0*FXFloatVal(size->getText()));
     if(selected.size<60) selected.size=60;
     if(selected.size>2400) selected.size=2400;
     previewFont();
@@ -464,8 +464,8 @@ long FontSelector::onCmdSizeText(FXObject*,FXSelector,void*)
 // User clicked up directory button
 long FontSelector::onCmdStyle(FXObject*,FXSelector,void* ptr)
 {
-    selected.slant=(FXuint)(FXuval)stylelist->getItemData((FXint)(FXival)ptr);
-    style->setText(stylelist->getItemText((FXint)(FXival)ptr));
+    selected.slant=(unsigned int)(FXuval)stylelist->getItemData((int)(FXival)ptr);
+    style->setText(stylelist->getItemText((int)(FXival)ptr));
     listFontSizes();
     previewFont();
     return 1;
@@ -482,8 +482,8 @@ long FontSelector::onCmdStyleText(FXObject*,FXSelector,void*)
 // Character set
 long FontSelector::onCmdCharset(FXObject*,FXSelector,void*)
 {
-    FXint index=charset->getCurrentItem();
-    FXuint enc=(FXuint)(FXuval)charset->getItemData(index);
+    int index=charset->getCurrentItem();
+    unsigned int enc=(unsigned int)(FXuval)charset->getItemData(index);
     selected.encoding=(FXFontEncoding)enc;
     listFontFaces();
     listWeights();
@@ -505,8 +505,8 @@ long FontSelector::onUpdCharset(FXObject*,FXSelector,void*)
 // Changed set width
 long FontSelector::onCmdSetWidth(FXObject*,FXSelector,void*)
 {
-    FXint index=setwidth->getCurrentItem();
-    selected.setwidth=(FXuint)(FXuval)setwidth->getItemData(index);
+    int index=setwidth->getCurrentItem();
+    selected.setwidth=(unsigned int)(FXuval)setwidth->getItemData(index);
     listFontFaces();
     listWeights();
     listSlants();
@@ -527,9 +527,9 @@ long FontSelector::onUpdSetWidth(FXObject*,FXSelector,void*)
 // Changed pitch
 long FontSelector::onCmdPitch(FXObject*,FXSelector,void*)
 {
-    FXint index=pitch->getCurrentItem();
+    int index=pitch->getCurrentItem();
     selected.flags&=~(FXFont::Fixed|FXFont::Variable);
-    selected.flags|=(FXuint)(FXuval)pitch->getItemData(index);
+    selected.flags|=(unsigned int)(FXuval)pitch->getItemData(index);
     listFontFaces();
     listWeights();
     listSlants();
@@ -716,7 +716,7 @@ FXIMPLEMENT(FontDialog,DialogBox,NULL,0)
 
 
 // Separator item
-FontDialog::FontDialog(FXWindow* owner,const FXString& name,FXuint opts,FXint x,FXint y,FXint w,FXint h):
+FontDialog::FontDialog(FXWindow* owner,const FXString& name,unsigned int opts,int x,int y,int w,int h):
         DialogBox(owner,name,opts|DECOR_TITLE|DECOR_BORDER|DECOR_RESIZE,x,y,w,h,0,0,0,0,4,4)
 {
     fontbox=new FontSelector(this,NULL,0,LAYOUT_FILL_X|LAYOUT_FILL_Y);
