@@ -17,7 +17,7 @@ extern FXString homedir;
 // Object implementation
 FXIMPLEMENT(ComboBox,FXComboBox,NULL,0)
 
-ComboBox::ComboBox(FXComposite *p,FXint cols,FXObject* tgt,FXSelector sel,FXuint opts):
+ComboBox::ComboBox(FXComposite *p,int cols,FXObject* tgt,FXSelector sel,unsigned int opts):
 		FXComboBox(p,cols,tgt,sel,opts)
 {}
 
@@ -38,7 +38,7 @@ FXDEFMAP(HistInputDialog) HistInputDialogMap[]=
 FXIMPLEMENT(HistInputDialog,DialogBox,HistInputDialogMap,ARRAYNUMBER(HistInputDialogMap))
 
 // Construct a dialog box with an optional check box
-HistInputDialog::HistInputDialog(FXWindow* w,FXString inp,FXString message,FXString title,FXString label,FXIcon *ic,  FXuint browse, FXbool option, FXString optiontext):
+HistInputDialog::HistInputDialog(FXWindow* w,FXString inp,FXString message,FXString title,FXString label,FXIcon *ic,  unsigned int browse, FXbool option, FXString optiontext):
         DialogBox(w,title,DECOR_TITLE|DECOR_BORDER|DECOR_STRETCHABLE)
 {
     // Browse type flag
@@ -139,7 +139,7 @@ long HistInputDialog::onCmdBrowsePath(FXObject* o,FXSelector s,void* p)
 	// File dialog
 	FileDialog browse(this,title);	
 	
-	const FXchar *patterns[]=
+	const char *patterns[]=
 		{
 			_("All Files"),          "*",	NULL
 		};
