@@ -2146,7 +2146,7 @@ long IconList::onQueryTip(FXObject* sender,FXSelector sel,void* ptr)
 				if (type==_("Folder") || type==_("Mount point"))
 				{
 					// Compute root file size
-					FXulong dnsize;
+					unsigned long long dnsize;
 					char dsize[64];
 					dnsize=::dirsize(pathname.text());
 					snprintf(dsize,sizeof(dsize)-1,"%llu",dnsize);
