@@ -85,31 +85,31 @@ KeybindingsBox::KeybindingsBox(FXWindow *win, FXStringDict* glbbindings, FXStrin
     
 	// First tab is global key bindings
 	new FXTabItem(tabbook,_("&Global Key Bindings"),NULL);
-    FXVerticalFrame *frame1=new FXVerticalFrame(tabbook,LAYOUT_SIDE_TOP|FRAME_THICK|FRAME_RAISED|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+    FXVerticalFrame *frame1=new FXVerticalFrame(tabbook,LAYOUT_SIDE_TOP|FRAME_RAISED|LAYOUT_FILL_X|LAYOUT_FILL_Y);
 	new FXLabel(frame1,_("These key bindings are common to all Xfe applications.\nDouble click on an item to modify the selected key binding..."),NULL,LAYOUT_LEFT|JUSTIFY_LEFT,0,0,0,0,0,0,20,20);
 	glbBindingsList=new IconList(frame1,this,ID_GLB_BINDINGS_LIST,_ICONLIST_STANDARD|HSCROLLER_NEVER|ICONLIST_BROWSESELECT|LAYOUT_SIDE_TOP|LAYOUT_LEFT|LAYOUT_FILL_X|LAYOUT_FILL_Y);
 
 	// Second tab is Xfe key bindings
 	new FXTabItem(tabbook,_("Xf&e Key Bindings"),NULL);
-    FXVerticalFrame *frame2=new FXVerticalFrame(tabbook,LAYOUT_SIDE_TOP|FRAME_THICK|FRAME_RAISED|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+    FXVerticalFrame *frame2=new FXVerticalFrame(tabbook,LAYOUT_SIDE_TOP|FRAME_RAISED|LAYOUT_FILL_X|LAYOUT_FILL_Y);
 	new FXLabel(frame2,_("These key bindings are specific to the X File Explorer application.\nDouble click on an item to modify the selected key binding..."),NULL,LAYOUT_LEFT|JUSTIFY_LEFT,0,0,0,0,0,0,20,20);
 	xfeBindingsList=new IconList(frame2,this,ID_XFE_BINDINGS_LIST,_ICONLIST_STANDARD|HSCROLLER_NEVER|ICONLIST_BROWSESELECT|LAYOUT_SIDE_TOP|LAYOUT_LEFT|LAYOUT_FILL_X|LAYOUT_FILL_Y);
 
 	// Third tab is Xfi key bindings
     new FXTabItem(tabbook,_("Xf&i Key Bindings"),NULL);
-    FXVerticalFrame *frame3=new FXVerticalFrame(tabbook,LAYOUT_SIDE_TOP|FRAME_THICK|FRAME_RAISED|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+    FXVerticalFrame *frame3=new FXVerticalFrame(tabbook,LAYOUT_SIDE_TOP|FRAME_RAISED|LAYOUT_FILL_X|LAYOUT_FILL_Y);
 	new FXLabel(frame3,_("These key bindings are specific to the X File Image application.\nDouble click on an item to modify the selected key binding..."),NULL,LAYOUT_LEFT|JUSTIFY_LEFT,0,0,0,0,0,0,20,20);
 	xfiBindingsList=new IconList(frame3,this,ID_XFI_BINDINGS_LIST,_ICONLIST_STANDARD|HSCROLLER_NEVER|ICONLIST_BROWSESELECT|LAYOUT_SIDE_TOP|LAYOUT_LEFT|LAYOUT_FILL_X|LAYOUT_FILL_Y);
 
 	// Fourth tab is Xfw key bindings
     new FXTabItem(tabbook,_("Xf&w Key Bindings"),NULL);
-    FXVerticalFrame *frame4=new FXVerticalFrame(tabbook,LAYOUT_SIDE_TOP|FRAME_THICK|FRAME_RAISED|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+    FXVerticalFrame *frame4=new FXVerticalFrame(tabbook,LAYOUT_SIDE_TOP|FRAME_RAISED|LAYOUT_FILL_X|LAYOUT_FILL_Y);
 	new FXLabel(frame4,_("These key bindings are specific to the X File Write application.\nDouble click on an item to modify the selected key binding..."),NULL,LAYOUT_LEFT|JUSTIFY_LEFT,0,0,0,0,0,0,20,20);
 	xfwBindingsList=new IconList(frame4,this,ID_XFW_BINDINGS_LIST,_ICONLIST_STANDARD|HSCROLLER_NEVER|ICONLIST_BROWSESELECT|LAYOUT_SIDE_TOP|LAYOUT_LEFT|LAYOUT_FILL_X|LAYOUT_FILL_Y);
 
     // Set list headers name and size 
-	FXuint hsize1=getWidth()/2-50;
-	FXuint hsize2=getWidth()/4;
+	unsigned int hsize1=getWidth()/2-50;
+	unsigned int hsize2=getWidth()/4;
 	
 	glbBindingsList->appendHeader(_("Action Name"),NULL,hsize1);
 	glbBindingsList->appendHeader(_("Registry Key"),NULL,hsize2);
@@ -149,7 +149,7 @@ void KeybindingsBox::create()
 {
     DialogBox::create();
 
-	FXint i;
+	int i;
 	FXString str, data, action, keybinding;
 	
 	// Fullfill the four lists
@@ -227,28 +227,28 @@ long KeybindingsBox::onCmdAccept(FXObject* o,FXSelector s,void* p)
 	{
 		// Write keybindings to the registry
 		FXString data, regkey, keybinding;
-		for (FXint i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
+		for (int i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
 		{
 			regkey=glbBindingsDict->key(i);
 			data=glbBindingsDict->data(i);
 			keybinding=data.after('\t');		
   			getApp()->reg().writeStringEntry("KEYBINDINGS",regkey.text(),keybinding.text());
 		}
-		for (FXint i=xfeBindingsDict->first(); i<xfeBindingsDict->size(); i=xfeBindingsDict->next(i))
+		for (int i=xfeBindingsDict->first(); i<xfeBindingsDict->size(); i=xfeBindingsDict->next(i))
 		{
 			regkey=xfeBindingsDict->key(i);
 			data=xfeBindingsDict->data(i);
 			keybinding=data.after('\t');		
   			getApp()->reg().writeStringEntry("KEYBINDINGS",regkey.text(),keybinding.text());
 		}
-		for (FXint i=xfiBindingsDict->first(); i<xfiBindingsDict->size(); i=xfiBindingsDict->next(i))
+		for (int i=xfiBindingsDict->first(); i<xfiBindingsDict->size(); i=xfiBindingsDict->next(i))
 		{
 			regkey=xfiBindingsDict->key(i);
 			data=xfiBindingsDict->data(i);
 			keybinding=data.after('\t');		
   			getApp()->reg().writeStringEntry("KEYBINDINGS",regkey.text(),keybinding.text());
 		}
-		for (FXint i=xfwBindingsDict->first(); i<xfwBindingsDict->size(); i=xfwBindingsDict->next(i))
+		for (int i=xfwBindingsDict->first(); i<xfwBindingsDict->size(); i=xfwBindingsDict->next(i))
 		{
 			regkey=xfwBindingsDict->key(i);
 			data=xfwBindingsDict->data(i);
@@ -276,25 +276,25 @@ long KeybindingsBox::onCmdCancel(FXObject* o,FXSelector s,void* p)
 {
 	// Restore initial (i.e. before modification) binding dicts
  	FXString data, regkey;
-    for (FXint i=glbBindingsDict_prev->first(); i<glbBindingsDict_prev->size(); i=glbBindingsDict_prev->next(i))
+    for (int i=glbBindingsDict_prev->first(); i<glbBindingsDict_prev->size(); i=glbBindingsDict_prev->next(i))
 	{
 		regkey=glbBindingsDict_prev->key(i);
 		data=glbBindingsDict_prev->data(i);
 		glbBindingsDict->replace(regkey.text(),data.text());
 	}
-    for (FXint i=xfeBindingsDict_prev->first(); i<xfeBindingsDict_prev->size(); i=xfeBindingsDict_prev->next(i))
+    for (int i=xfeBindingsDict_prev->first(); i<xfeBindingsDict_prev->size(); i=xfeBindingsDict_prev->next(i))
 	{
 		regkey=xfeBindingsDict_prev->key(i);
 		data=xfeBindingsDict_prev->data(i);
 		xfeBindingsDict->replace(regkey.text(),data.text());
 	}
-    for (FXint i=xfiBindingsDict_prev->first(); i<xfiBindingsDict_prev->size(); i=xfiBindingsDict_prev->next(i))
+    for (int i=xfiBindingsDict_prev->first(); i<xfiBindingsDict_prev->size(); i=xfiBindingsDict_prev->next(i))
 	{
 		regkey=xfiBindingsDict_prev->key(i);
 		data=xfiBindingsDict_prev->data(i);
 		xfiBindingsDict->replace(regkey.text(),data.text());
 	}
-    for (FXint i=xfwBindingsDict_prev->first(); i<xfwBindingsDict_prev->size(); i=xfwBindingsDict_prev->next(i))
+    for (int i=xfwBindingsDict_prev->first(); i<xfwBindingsDict_prev->size(); i=xfwBindingsDict_prev->next(i))
 	{
 		regkey=xfwBindingsDict_prev->key(i);
 		data=xfwBindingsDict_prev->data(i);
@@ -310,15 +310,15 @@ long KeybindingsBox::onCmdCancel(FXObject* o,FXSelector s,void* p)
 
 
 // Compare sectioned strings
-FXint KeybindingsBox::compareSection(const FXchar *p,const FXchar* q,FXint s)
+int KeybindingsBox::compareSection(const char *p,const char* q,int s)
 {
-    register FXint c1,c2,x;
+    register int c1,c2,x;
     for (x=s; x && *p; x-=(*p++=='\t'));
     for (x=s; x && *q; x-=(*q++=='\t'));
     do
     {
-        c1=FXuchar(*p++);
-        c2=FXuchar(*q++);
+        c1=(unsigned char)(*p++);
+        c2=(unsigned char)(*q++);
     }
     while ('\t'<c1 && (c1==c2));
     return c1-c2;
@@ -326,36 +326,36 @@ FXint KeybindingsBox::compareSection(const FXchar *p,const FXchar* q,FXint s)
 
 
 // Sort functions
-FXint KeybindingsBox::ascendingActionName(const IconItem* a,const IconItem* b)
+int KeybindingsBox::ascendingActionName(const IconItem* a,const IconItem* b)
 {
     return compareSection(a->getText().text(),b->getText().text(),0);
 }
 
 
-FXint KeybindingsBox::descendingActionName(const IconItem* a,const IconItem* b)
+int KeybindingsBox::descendingActionName(const IconItem* a,const IconItem* b)
 {
     return compareSection(b->getText().text(),a->getText().text(),0);
 }
 
-FXint KeybindingsBox::ascendingRegistryKey(const IconItem* a,const IconItem* b)
+int KeybindingsBox::ascendingRegistryKey(const IconItem* a,const IconItem* b)
 {
     return compareSection(a->getText().text(),b->getText().text(),1);
 }
 
 
-FXint KeybindingsBox::descendingRegistryKey(const IconItem* a,const IconItem* b)
+int KeybindingsBox::descendingRegistryKey(const IconItem* a,const IconItem* b)
 {
     return compareSection(b->getText().text(),a->getText().text(),1);
 }
 
 
-FXint KeybindingsBox::ascendingKeybinding(const IconItem* a,const IconItem* b)
+int KeybindingsBox::ascendingKeybinding(const IconItem* a,const IconItem* b)
 {
     return compareSection(a->getText().text(),b->getText().text(),2);
 }
 
 
-FXint KeybindingsBox::descendingKeybinding(const IconItem* a,const IconItem* b)
+int KeybindingsBox::descendingKeybinding(const IconItem* a,const IconItem* b)
 {
     return compareSection(b->getText().text(),a->getText().text(),2);
 }
@@ -368,7 +368,7 @@ long KeybindingsBox::onCmdGlbSortByActionName(FXObject*,FXSelector,void*)
 	glbBindingsList->setSortHeader(0);
 	glbBindingsList->clearItems();
     FXString str, data, action, keybinding;
-	for(FXint i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
+	for(int i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
 	{	
 		data=glbBindingsDict->data(i);
 		action= data.before('\t');
@@ -389,7 +389,7 @@ long KeybindingsBox::onCmdGlbSortByRegistryKey(FXObject*,FXSelector,void*)
 	glbBindingsList->setSortHeader(1);
 	glbBindingsList->clearItems();
     FXString str, data, action, keybinding;
-    for(FXint i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
+    for(int i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
 	{
 		data=glbBindingsDict->data(i);
 		action= data.before('\t');
@@ -409,7 +409,7 @@ long KeybindingsBox::onCmdGlbSortByKeyBinding(FXObject*,FXSelector,void*)
 	glbBindingsList->setSortHeader(2);
 	glbBindingsList->clearItems();
     FXString str, data, action, keybinding;
-    for(FXint i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
+    for(int i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
 	{
 		data=glbBindingsDict->data(i);
 		action= data.before('\t');
@@ -430,7 +430,7 @@ long KeybindingsBox::onCmdXfeSortByActionName(FXObject*,FXSelector,void*)
 	xfeBindingsList->setSortHeader(0);
 	xfeBindingsList->clearItems();
     FXString str, data, action, keybinding;
-	for(FXint i=xfeBindingsDict->first(); i<xfeBindingsDict->size(); i=xfeBindingsDict->next(i))
+	for(int i=xfeBindingsDict->first(); i<xfeBindingsDict->size(); i=xfeBindingsDict->next(i))
 	{	
 		data=xfeBindingsDict->data(i);
 		action= data.before('\t');
@@ -450,7 +450,7 @@ long KeybindingsBox::onCmdXfeSortByRegistryKey(FXObject*,FXSelector,void*)
 	xfeBindingsList->setSortHeader(1);
 	xfeBindingsList->clearItems();
     FXString str, data, action, keybinding;
-    for(FXint i=xfeBindingsDict->first(); i<xfeBindingsDict->size(); i=xfeBindingsDict->next(i))
+    for(int i=xfeBindingsDict->first(); i<xfeBindingsDict->size(); i=xfeBindingsDict->next(i))
 	{
 		data=xfeBindingsDict->data(i);
 		action= data.before('\t');
@@ -470,7 +470,7 @@ long KeybindingsBox::onCmdXfeSortByKeyBinding(FXObject*,FXSelector,void*)
 	xfeBindingsList->setSortHeader(2);
 	xfeBindingsList->clearItems();
     FXString str, data, action, keybinding;
-    for(FXint i=xfeBindingsDict->first(); i<xfeBindingsDict->size(); i=xfeBindingsDict->next(i))
+    for(int i=xfeBindingsDict->first(); i<xfeBindingsDict->size(); i=xfeBindingsDict->next(i))
 	{
 		data=xfeBindingsDict->data(i);
 		action= data.before('\t');
@@ -490,7 +490,7 @@ long KeybindingsBox::onCmdXfiSortByActionName(FXObject*,FXSelector,void*)
 	xfiBindingsList->setSortHeader(0);
 	xfiBindingsList->clearItems();
     FXString str, data, action, keybinding;
-	for(FXint i=xfiBindingsDict->first(); i<xfiBindingsDict->size(); i=xfiBindingsDict->next(i))
+	for(int i=xfiBindingsDict->first(); i<xfiBindingsDict->size(); i=xfiBindingsDict->next(i))
 	{
 		data=xfiBindingsDict->data(i);
 		action= data.before('\t');
@@ -510,7 +510,7 @@ long KeybindingsBox::onCmdXfiSortByRegistryKey(FXObject*,FXSelector,void*)
 	xfiBindingsList->setSortHeader(1);
 	xfiBindingsList->clearItems();
     FXString str, data, action, keybinding;
-    for(FXint i=xfiBindingsDict->first(); i<xfiBindingsDict->size(); i=xfiBindingsDict->next(i))
+    for(int i=xfiBindingsDict->first(); i<xfiBindingsDict->size(); i=xfiBindingsDict->next(i))
 	{
 		data=xfiBindingsDict->data(i);
 		action= data.before('\t');
@@ -530,7 +530,7 @@ long KeybindingsBox::onCmdXfiSortByKeyBinding(FXObject*,FXSelector,void*)
 	xfiBindingsList->setSortHeader(2);
 	xfiBindingsList->clearItems();
     FXString str, data, action, keybinding;
-    for(FXint i=xfiBindingsDict->first(); i<xfiBindingsDict->size(); i=xfiBindingsDict->next(i))
+    for(int i=xfiBindingsDict->first(); i<xfiBindingsDict->size(); i=xfiBindingsDict->next(i))
 	{
 		data=xfiBindingsDict->data(i);
 		action= data.before('\t');
@@ -551,7 +551,7 @@ long KeybindingsBox::onCmdXfwSortByActionName(FXObject*,FXSelector,void*)
 	xfwBindingsList->setSortHeader(0);
 	xfwBindingsList->clearItems();
     FXString str, data, action, keybinding;
-	for(FXint i=xfwBindingsDict->first(); i<xfwBindingsDict->size(); i=xfwBindingsDict->next(i))
+	for(int i=xfwBindingsDict->first(); i<xfwBindingsDict->size(); i=xfwBindingsDict->next(i))
 	{
 		data=xfwBindingsDict->data(i);
 		action= data.before('\t');
@@ -571,7 +571,7 @@ long KeybindingsBox::onCmdXfwSortByRegistryKey(FXObject*,FXSelector,void*)
 	xfwBindingsList->setSortHeader(1);
 	xfwBindingsList->clearItems();
     FXString str, data, action, keybinding;
-    for(FXint i=xfwBindingsDict->first(); i<xfwBindingsDict->size(); i=xfwBindingsDict->next(i))
+    for(int i=xfwBindingsDict->first(); i<xfwBindingsDict->size(); i=xfwBindingsDict->next(i))
 	{
 		data=xfwBindingsDict->data(i);
 		action= data.before('\t');
@@ -591,7 +591,7 @@ long KeybindingsBox::onCmdXfwSortByKeyBinding(FXObject*,FXSelector,void*)
 	xfwBindingsList->setSortHeader(2);
 	xfwBindingsList->clearItems();
     FXString str, data, action, keybinding;
-    for(FXint i=xfwBindingsDict->first(); i<xfwBindingsDict->size(); i=xfwBindingsDict->next(i))
+    for(int i=xfwBindingsDict->first(); i<xfwBindingsDict->size(); i=xfwBindingsDict->next(i))
 	{
 		data=xfwBindingsDict->data(i);
 		action= data.before('\t');
@@ -608,7 +608,7 @@ long KeybindingsBox::onCmdXfwSortByKeyBinding(FXObject*,FXSelector,void*)
 // Clicked on a global list header button
 long KeybindingsBox::onCmdGlbHeaderClicked(FXObject*,FXSelector,void* ptr)
 {	
-	FXuint num=(FXuint)(FXuval)ptr;
+	unsigned int num=(unsigned int)(FXuval)ptr;
 		
 	if (num >= 0 && num <3)
 	{
@@ -627,7 +627,7 @@ long KeybindingsBox::onCmdGlbHeaderClicked(FXObject*,FXSelector,void* ptr)
 // Clicked on a Xfe list header button
 long KeybindingsBox::onCmdXfeHeaderClicked(FXObject*,FXSelector,void* ptr)
 {	
-	FXuint num=(FXuint)(FXuval)ptr;
+	unsigned int num=(unsigned int)(FXuval)ptr;
 		
 	if (num >= 0 && num <3)
 	{
@@ -645,7 +645,7 @@ long KeybindingsBox::onCmdXfeHeaderClicked(FXObject*,FXSelector,void* ptr)
 // Clicked on a Xfi list header button
 long KeybindingsBox::onCmdXfiHeaderClicked(FXObject*,FXSelector,void* ptr)
 {
-	FXuint num=(FXuint)(FXuval)ptr;
+	unsigned int num=(unsigned int)(FXuval)ptr;
 	if (num >= 0 && num <3)
 	{
 		if (num==0)
@@ -662,7 +662,7 @@ long KeybindingsBox::onCmdXfiHeaderClicked(FXObject*,FXSelector,void* ptr)
 // Clicked on a Xfw list header button
 long KeybindingsBox::onCmdXfwHeaderClicked(FXObject*,FXSelector,void* ptr)
 {
-	FXuint num=(FXuint)(FXuval)ptr;
+	unsigned int num=(unsigned int)(FXuval)ptr;
 	if (num >= 0 && num <3)
 	{
 		if (num==0)
@@ -762,8 +762,8 @@ long KeybindingsBox::onCmdDefineGlbKeybindings(FXObject*,FXSelector,void*)
 {
 	// Get selected item string
 	FXString itemtext="";
-	FXint index=-1;
-	for (FXint u=0; u< glbBindingsList->getNumItems (); u++)
+	int index=-1;
+	for (int u=0; u< glbBindingsList->getNumItems (); u++)
 	{
 		if (glbBindingsList->isItemSelected(u))
 		{
@@ -799,7 +799,7 @@ long KeybindingsBox::onCmdDefineGlbKeybindings(FXObject*,FXSelector,void*)
 		{
 			FXString dictdata, dictkey;
 			FXbool exist_in_glb=FALSE, exist_in_xfe=FALSE, exist_in_xfi=FALSE, exist_in_xfw=FALSE;
-			for(FXint i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
+			for(int i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
 			{
 				dictdata=glbBindingsDict->data(i);
 				dictkey=dictdata.after('\t');
@@ -817,7 +817,7 @@ long KeybindingsBox::onCmdDefineGlbKeybindings(FXObject*,FXSelector,void*)
 				delete kbdialog;
 				return 0;
 			}
-			for(FXint i=xfeBindingsDict->first(); i<xfeBindingsDict->size(); i=xfeBindingsDict->next(i))
+			for(int i=xfeBindingsDict->first(); i<xfeBindingsDict->size(); i=xfeBindingsDict->next(i))
 			{
 				dictdata=xfeBindingsDict->data(i);
 				dictkey=dictdata.after('\t');
@@ -835,7 +835,7 @@ long KeybindingsBox::onCmdDefineGlbKeybindings(FXObject*,FXSelector,void*)
 				delete kbdialog;
 				return 0;
 			}
-			for(FXint i=xfiBindingsDict->first(); i<xfiBindingsDict->size(); i=xfiBindingsDict->next(i))
+			for(int i=xfiBindingsDict->first(); i<xfiBindingsDict->size(); i=xfiBindingsDict->next(i))
 			{
 				dictdata=xfiBindingsDict->data(i);
 				dictkey=dictdata.after('\t');
@@ -853,7 +853,7 @@ long KeybindingsBox::onCmdDefineGlbKeybindings(FXObject*,FXSelector,void*)
 				delete kbdialog;
 				return 0;
 			}
-			for(FXint i=xfwBindingsDict->first(); i<xfwBindingsDict->size(); i=xfwBindingsDict->next(i))
+			for(int i=xfwBindingsDict->first(); i<xfwBindingsDict->size(); i=xfwBindingsDict->next(i))
 			{
 				dictdata=xfwBindingsDict->data(i);
 				dictkey=dictdata.after('\t');
@@ -902,8 +902,8 @@ long KeybindingsBox::onCmdDefineXfeKeybindings(FXObject*,FXSelector,void*)
 {
 	// Get selected item string
 	FXString itemtext="";
-	FXint index=-1;
-	for (FXint u=0; u< xfeBindingsList->getNumItems (); u++)
+	int index=-1;
+	for (int u=0; u< xfeBindingsList->getNumItems (); u++)
 	{
 		if (xfeBindingsList->isItemSelected(u))
 		{
@@ -939,7 +939,7 @@ long KeybindingsBox::onCmdDefineXfeKeybindings(FXObject*,FXSelector,void*)
 		{
 			FXString dictdata, dictkey;
 			FXbool exist_in_glb=FALSE, exist_in_xfe=FALSE;
-			for(FXint i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
+			for(int i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
 			{
 				dictdata=glbBindingsDict->data(i);
 				dictkey=dictdata.after('\t');
@@ -957,7 +957,7 @@ long KeybindingsBox::onCmdDefineXfeKeybindings(FXObject*,FXSelector,void*)
 				delete kbdialog;
 				return 0;
 			}
-			for(FXint i=xfeBindingsDict->first(); i<xfeBindingsDict->size(); i=xfeBindingsDict->next(i))
+			for(int i=xfeBindingsDict->first(); i<xfeBindingsDict->size(); i=xfeBindingsDict->next(i))
 			{
 				dictdata=xfeBindingsDict->data(i);
 				dictkey=dictdata.after('\t');
@@ -1006,8 +1006,8 @@ long KeybindingsBox::onCmdDefineXfiKeybindings(FXObject*,FXSelector,void*)
 {
 	// Get selected item string
 	FXString itemtext="";
-	FXint index=-1;
-	for (FXint u=0; u< xfiBindingsList->getNumItems (); u++)
+	int index=-1;
+	for (int u=0; u< xfiBindingsList->getNumItems (); u++)
 	{
 		if (xfiBindingsList->isItemSelected(u))
 		{
@@ -1043,7 +1043,7 @@ long KeybindingsBox::onCmdDefineXfiKeybindings(FXObject*,FXSelector,void*)
 		{
 			FXString dictdata, dictkey;
 			FXbool exist_in_glb=FALSE, exist_in_xfi=FALSE;
-			for(FXint i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
+			for(int i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
 			{
 				dictdata=glbBindingsDict->data(i);
 				dictkey=dictdata.after('\t');
@@ -1061,7 +1061,7 @@ long KeybindingsBox::onCmdDefineXfiKeybindings(FXObject*,FXSelector,void*)
 				delete kbdialog;
 				return 0;
 			}
-			for(FXint i=xfiBindingsDict->first(); i<xfiBindingsDict->size(); i=xfiBindingsDict->next(i))
+			for(int i=xfiBindingsDict->first(); i<xfiBindingsDict->size(); i=xfiBindingsDict->next(i))
 			{
 				dictdata=xfiBindingsDict->data(i);
 				dictkey=dictdata.after('\t');
@@ -1110,8 +1110,8 @@ long KeybindingsBox::onCmdDefineXfwKeybindings(FXObject*,FXSelector,void*)
 {
 	// Get selected item string
 	FXString itemtext="";
-	FXint index=-1;
-	for (FXint u=0; u< xfwBindingsList->getNumItems (); u++)
+	int index=-1;
+	for (int u=0; u< xfwBindingsList->getNumItems (); u++)
 	{
 		if (xfwBindingsList->isItemSelected(u))
 		{
@@ -1147,7 +1147,7 @@ long KeybindingsBox::onCmdDefineXfwKeybindings(FXObject*,FXSelector,void*)
 		{
 			FXString dictdata, dictkey;
 			FXbool exist_in_glb=FALSE, exist_in_xfw=FALSE;
-			for(FXint i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
+			for(int i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
 			{
 				dictdata=glbBindingsDict->data(i);
 				dictkey=dictdata.after('\t');
@@ -1165,7 +1165,7 @@ long KeybindingsBox::onCmdDefineXfwKeybindings(FXObject*,FXSelector,void*)
 				delete kbdialog;
 				return 0;
 			}
-			for(FXint i=xfwBindingsDict->first(); i<xfwBindingsDict->size(); i=xfwBindingsDict->next(i))
+			for(int i=xfwBindingsDict->first(); i<xfwBindingsDict->size(); i=xfwBindingsDict->next(i))
 			{
 				dictdata=xfwBindingsDict->data(i);
 				dictkey=dictdata.after('\t');
@@ -1210,29 +1210,29 @@ long KeybindingsBox::onCmdDefineXfwKeybindings(FXObject*,FXSelector,void*)
 
 
 // Execute dialog box modally
-FXuint KeybindingsBox::execute(FXuint placement)
+unsigned int KeybindingsBox::execute(unsigned int placement)
 {
 	// Save binding dicts for cancel purpose
  	FXString data, regkey;
-    for (FXint i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
+    for (int i=glbBindingsDict->first(); i<glbBindingsDict->size(); i=glbBindingsDict->next(i))
 	{
 		regkey=glbBindingsDict->key(i);
 		data=glbBindingsDict->data(i);
 		glbBindingsDict_prev->replace(regkey.text(),data.text());
 	}
-    for (FXint i=xfeBindingsDict->first(); i<xfeBindingsDict->size(); i=xfeBindingsDict->next(i))
+    for (int i=xfeBindingsDict->first(); i<xfeBindingsDict->size(); i=xfeBindingsDict->next(i))
 	{
 		regkey=xfeBindingsDict->key(i);
 		data=xfeBindingsDict->data(i);
 		xfeBindingsDict_prev->replace(regkey.text(),data.text());
 	}
-    for (FXint i=xfiBindingsDict->first(); i<xfiBindingsDict->size(); i=xfiBindingsDict->next(i))
+    for (int i=xfiBindingsDict->first(); i<xfiBindingsDict->size(); i=xfiBindingsDict->next(i))
 	{
 		regkey=xfiBindingsDict->key(i);
 		data=xfiBindingsDict->data(i);
 		xfiBindingsDict_prev->replace(regkey.text(),data.text());
 	}
-    for (FXint i=xfwBindingsDict->first(); i<xfwBindingsDict->size(); i=xfwBindingsDict->next(i))
+    for (int i=xfwBindingsDict->first(); i<xfwBindingsDict->size(); i=xfwBindingsDict->next(i))
 	{
 		regkey=xfwBindingsDict->key(i);
 		data=xfwBindingsDict->data(i);
@@ -1240,7 +1240,7 @@ FXuint KeybindingsBox::execute(FXuint placement)
 	}
  
 	// Execute dialog 
-	FXuint ret=DialogBox::execute(placement);
+	unsigned int ret=DialogBox::execute(placement);
     return ret;
 }
 
