@@ -36,7 +36,7 @@ protected:
 private:
     MessageBox(const MessageBox&);
     MessageBox &operator=(const MessageBox&);
-    void initialize(const FXString&,FXIcon*,FXuint,FXuint);
+    void initialize(const FXString&,FXIcon*,unsigned int,unsigned int);
     FXLabel* msg;
 public:
     long onCmdClicked(FXObject*,FXSelector,void*);
@@ -57,34 +57,34 @@ public:
 public:
 
     // Construct message box with given caption, icon, and message text
-    MessageBox(FXWindow* owner,const FXString& caption,const FXString& text,FXIcon* ic=NULL,FXuint opts=0,
-	           FXuint textopts=JUSTIFY_LEFT|ICON_BEFORE_TEXT|LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FILL_X|LAYOUT_FILL_Y,
-			   FXint x=0,FXint y=0);
+    MessageBox(FXWindow* owner,const FXString& caption,const FXString& text,FXIcon* ic=NULL,unsigned int opts=0,
+	           unsigned int textopts=JUSTIFY_LEFT|ICON_BEFORE_TEXT|LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FILL_X|LAYOUT_FILL_Y,
+			   int x=0,int y=0);
 
     // Construct free floating message box with given caption, icon, and message text
-    MessageBox(FXApp* a,const FXString& caption,const FXString& text,FXIcon* ic=NULL,FXuint opts=0,
-	           FXuint textopts=JUSTIFY_LEFT|ICON_BEFORE_TEXT|LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FILL_X|LAYOUT_FILL_Y,
-			   FXint x=0,FXint y=0);
+    MessageBox(FXApp* a,const FXString& caption,const FXString& text,FXIcon* ic=NULL,unsigned int opts=0,
+	           unsigned int textopts=JUSTIFY_LEFT|ICON_BEFORE_TEXT|LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FILL_X|LAYOUT_FILL_Y,
+			   int x=0,int y=0);
 
     // Show a modal error message.
     // The text message may contain printf-tyle formatting commands.
-    static FXuint error(FXWindow* owner,FXuint opts,const char* caption,const char* message,...) FX_PRINTF(4,5) ;
-    static FXuint error(FXApp* app,FXuint opts,const char* caption,const char* message,...) FX_PRINTF(4,5) ;
+    static unsigned int error(FXWindow* owner,unsigned int opts,const char* caption,const char* message,...) FX_PRINTF(4,5) ;
+    static unsigned int error(FXApp* app,unsigned int opts,const char* caption,const char* message,...) FX_PRINTF(4,5) ;
 
     // Show a modal warning message
     // The text message may contain printf-tyle formatting commands.
-    static FXuint warning(FXWindow* owner,FXuint opts,const char* caption,const char* message,...) FX_PRINTF(4,5) ;
-    static FXuint warning(FXApp* app,FXuint opts,const char* caption,const char* message,...) FX_PRINTF(4,5) ;
+    static unsigned int warning(FXWindow* owner,unsigned int opts,const char* caption,const char* message,...) FX_PRINTF(4,5) ;
+    static unsigned int warning(FXApp* app,unsigned int opts,const char* caption,const char* message,...) FX_PRINTF(4,5) ;
 
     // Show a modal question dialog
     // The text message may contain printf-tyle formatting commands.
-    static FXuint question(FXWindow* owner,FXuint opts,const char* caption,const char* message,...) FX_PRINTF(4,5) ;
-    static FXuint question(FXApp* app,FXuint opts,const char* caption,const char* message,...) FX_PRINTF(4,5) ;
+    static unsigned int question(FXWindow* owner,unsigned int opts,const char* caption,const char* message,...) FX_PRINTF(4,5) ;
+    static unsigned int question(FXApp* app,unsigned int opts,const char* caption,const char* message,...) FX_PRINTF(4,5) ;
 
     // Show a modal information dialog
     // The text message may contain printf-tyle formatting commands.
-    static FXuint information(FXWindow* owner,FXuint opts,const char* caption,const char* message,...) FX_PRINTF(4,5) ;
-    static FXuint information(FXApp* app,FXuint opts,const char* caption,const char* message,...) FX_PRINTF(4,5) ;
+    static unsigned int information(FXWindow* owner,unsigned int opts,const char* caption,const char* message,...) FX_PRINTF(4,5) ;
+    static unsigned int information(FXApp* app,unsigned int opts,const char* caption,const char* message,...) FX_PRINTF(4,5) ;
 
 	// Get message text
 	FXString getText(void)
