@@ -5,14 +5,13 @@
 #include "TextLabel.h"
 #include "FileList.h"
 #include "DirPanel.h"
-
+#include "xfedefs.h"
 
 class FXAPI PathLinker : public FXHorizontalFrame
 {
     FXDECLARE(PathLinker)
 
 public:
-#define MAX_LINKS 40
     enum ButtonIds
 	{
         ID_START_LINK = FXHorizontalFrame::ID_LAST,
