@@ -172,9 +172,9 @@ PreferencesBox::PreferencesBox(FXWindow *win, FXColor listbackcolor, FXColor lis
 	trashbypass=new FXCheckButton(group,_("Include a command to bypass the trash can (permanent delete)"),this,ID_TRASH_BYPASS);
     autosave=new FXCheckButton(group,_("Auto save layout"));
 	savewinpos=new FXCheckButton(group,_("Save window position"));
-    diropen=new FXCheckButton(group,_("Single click directory open"));
+    diropen=new FXCheckButton(group,_("Single click folder open"));
     fileopen=new FXCheckButton(group,_("Single click file open"),this,ID_SINGLE_CLICK_FILEOPEN);
-    filetooltips=new FXCheckButton(group,_("Display tooltips in file and directory lists"),this,ID_FILE_TOOLTIPS);
+    filetooltips=new FXCheckButton(group,_("Display tooltips in file and folder lists"),this,ID_FILE_TOOLTIPS);
     relativeresize=new FXCheckButton(group,_("Relative resizing of file lists"),this,ID_RELATIVE_RESIZE);
     showpathlink=new FXCheckButton(group,_("Display a path linker above file lists"),this,ID_SHOW_PATHLINK);
 #ifdef STARTUP_NOTIFICATION
@@ -182,7 +182,7 @@ PreferencesBox::PreferencesBox(FXWindow *win, FXColor listbackcolor, FXColor lis
 #endif
 
     FXMatrix *matrix = new FXMatrix(group,2,MATRIX_BY_COLUMNS|LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y);
-    new FXLabel(matrix,_("Date format used in file and directory lists:\n(Type 'man strftime' in a terminal for help on the format)"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
+    new FXLabel(matrix,_("Date format used in file and folder lists:\n(Type 'man strftime' in a terminal for help on the format)"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
     timeformat = new FXTextField(matrix,15,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW|LAYOUT_FILL_X);
     oldtimeformat=getApp()->reg().readStringEntry("SETTINGS","time_format",DEFAULT_TIME_FORMAT);
     timeformat->setText(oldtimeformat);
@@ -281,7 +281,7 @@ PreferencesBox::PreferencesBox(FXWindow *win, FXColor listbackcolor, FXColor lis
     dnd=new FXCheckButton(group,_("Confirm drag and drop"));
 	trashmv=new FXCheckButton(group,_("Confirm move to trash/restore from trash"),this,ID_CONFIRM_TRASH);
 	del=new FXCheckButton(group,_("Confirm delete"));
-	del_emptydir=new FXCheckButton(group,_("Confirm delete non empty directories"),this,ID_CONFIRM_DEL_EMPTYDIR);
+	del_emptydir=new FXCheckButton(group,_("Confirm delete non empty folders"),this,ID_CONFIRM_DEL_EMPTYDIR);
     overwrite=new FXCheckButton(group,_("Confirm overwrite"));
     exec=new FXCheckButton(group,_("Confirm execute text files"));
 
@@ -610,22 +610,22 @@ long PreferencesBox::onCmdChangeKeyBindings(FXObject*,FXSelector,void*)
 		glbBindingsDict=new FXStringDict();
 
 	key=getApp()->reg().readStringEntry("KEYBINDINGS","go_back","Ctrl-Backspace");
-	str=_("Go to previous directory")+TAB+key;
+	str=_("Go to previous folder")+TAB+key;
 	glbBindingsDict->insert("go_back",str.text());
 	
 	key=getApp()->reg().readStringEntry("KEYBINDINGS","go_forward","Shift-Backspace");
-	str=_("Go to next directory")+TAB+key;
+	str=_("Go to next folder")+TAB+key;
 	glbBindingsDict->insert("go_forward",str.text());
 
 	key=getApp()->reg().readStringEntry("KEYBINDINGS","go_up","Backspace");
-	str=_("Go to parent directory")+TAB+key;
+	str=_("Go to parent folder")+TAB+key;
 	glbBindingsDict->insert("go_up",str.text());
 	
 	key=getApp()->reg().readStringEntry("KEYBINDINGS","go_home","Ctrl-H");
-	str=_("Go to home directory")+TAB+key;
+	str=_("Go to home folder")+TAB+key;
 	glbBindingsDict->insert("go_home",str.text());
 
-	key=getApp()->reg().readStringEntry("KEYBINDINGS","new_file","F2");
+	key=getApp()->reg().readStringEntry("KEYBINDINGS","new_file","ctrl-N");
 	str=_("Create new file")+TAB+key;
 	glbBindingsDict->insert("new_file",str.text());
 
@@ -690,7 +690,7 @@ long PreferencesBox::onCmdChangeKeyBindings(FXObject*,FXSelector,void*)
 	glbBindingsDict->insert("thumbnails",str.text());
 
 	key=getApp()->reg().readStringEntry("KEYBINDINGS","go_work","Shift-F2");
- 	str=_("Go to working directory")+TAB+key;
+ 	str=_("Go to working folder")+TAB+key;
 	glbBindingsDict->insert("go_work",str.text());
 
 	key=getApp()->reg().readStringEntry("KEYBINDINGS","close","Ctrl-W");
@@ -788,7 +788,7 @@ long PreferencesBox::onCmdChangeKeyBindings(FXObject*,FXSelector,void*)
  	str=_("Clear location bar")+TAB+key;
 	xfeBindingsDict->insert("clear_location",str.text());
 
-	key=getApp()->reg().readStringEntry("KEYBINDINGS","rename","Ctrl-N");
+	key=getApp()->reg().readStringEntry("KEYBINDINGS","rename","F2");
  	str=_("Rename file")+TAB+key;
 	xfeBindingsDict->insert("rename",str.text());
 
@@ -833,7 +833,7 @@ long PreferencesBox::onCmdChangeKeyBindings(FXObject*,FXSelector,void*)
 	xfeBindingsDict->insert("edit",str.text());
 
  	key=getApp()->reg().readStringEntry("KEYBINDINGS","hidden_dirs","Ctrl-F5");
- 	str=_("Toggle display hidden directories")+TAB+key;
+ 	str=_("Toggle display hidden folders")+TAB+key;
 	xfeBindingsDict->insert("hidden_dirs",str.text());
 
  	key=getApp()->reg().readStringEntry("KEYBINDINGS","filter","Ctrl-D");
@@ -940,7 +940,7 @@ long PreferencesBox::onCmdRestoreKeyBindings(FXObject*,FXSelector,void*)
 	getApp()->reg().writeStringEntry("KEYBINDINGS","go_forward","Shift-Backspace");
 	getApp()->reg().writeStringEntry("KEYBINDINGS","go_up","Backspace");
 	getApp()->reg().writeStringEntry("KEYBINDINGS","go_home","Ctrl-H");
-	getApp()->reg().writeStringEntry("KEYBINDINGS","new_file","F2");
+	getApp()->reg().writeStringEntry("KEYBINDINGS","new_file","Ctrl-N");
 	getApp()->reg().writeStringEntry("KEYBINDINGS","new_folder","F7");
 	getApp()->reg().writeStringEntry("KEYBINDINGS","copy","Ctrl-C");
 	getApp()->reg().writeStringEntry("KEYBINDINGS","cut","Ctrl-X");
@@ -983,7 +983,7 @@ long PreferencesBox::onCmdRestoreKeyBindings(FXObject*,FXSelector,void*)
   	getApp()->reg().writeStringEntry("KEYBINDINGS","two_panels","Ctrl-F3");
   	getApp()->reg().writeStringEntry("KEYBINDINGS","tree_two_panels","Ctrl-F4");
   	getApp()->reg().writeStringEntry("KEYBINDINGS","clear_location","Ctrl-L");
-	getApp()->reg().writeStringEntry("KEYBINDINGS","rename","Ctrl-N");
+	getApp()->reg().writeStringEntry("KEYBINDINGS","rename","F2");
 	getApp()->reg().writeStringEntry("KEYBINDINGS","copy_to","F5");
 	getApp()->reg().writeStringEntry("KEYBINDINGS","move_to","F6");
 	getApp()->reg().writeStringEntry("KEYBINDINGS","symlink_to","Ctrl-S");
