@@ -8,10 +8,10 @@
 
 
 // Number of modifiable colors
-#define NUM_COLORS 11
+#define NUM_COLORS 12
 
 // Number of themes
-#define NUM_THEMES 13
+#define NUM_THEMES 12
 
 
 struct Theme
@@ -23,7 +23,7 @@ struct Theme
         name = "";
     };
     Theme(const char *n,FXColor base=0,FXColor bdr=0,FXColor bg=0,FXColor fg=0,
-	                    FXColor selbg=0,FXColor selfg=0, FXColor listbg=0, FXColor listfg=0, FXColor listhl=0, FXColor pbarfg=0, FXColor attenfg=0)
+	                    FXColor selbg=0,FXColor selfg=0, FXColor listbg=0, FXColor listfg=0, FXColor listhl=0, FXColor pbarfg=0, FXColor attenfg=0, FXColor scrollfg=0)
     {
         name = strdup(n);
         color[0] = base;
@@ -38,6 +38,7 @@ struct Theme
   		color[8] = listhl;
 		color[9] = pbarfg;
 		color[10]= attenfg;
+		color[11]= scrollfg;
 	};
     FXbool operator != (const Theme&);
 };
@@ -56,6 +57,7 @@ private:
     FXList     *themesList;
     FXTextField *iconpath;
     FXTextField *txteditor;
+    FXTextField *timeformat;
     FXTextField *txtviewer;
     FXTextField *imgviewer;
     FXTextField *xterm;
@@ -68,6 +70,7 @@ private:
     FXTextField *textfont;
     FXString    oldiconpath;
     FXString    oldtxteditor;
+    FXString    oldtimeformat;
     FXString    oldtxtviewer;
     FXString    oldimgviewer;
     FXString    oldxterm;
@@ -85,7 +88,6 @@ private:
     FXCheckButton  *filetooltips;
     FXCheckButton  *relativeresize;
     FXCheckButton  *showpathlink;
-    FXCheckButton  *quit;
     FXCheckButton  *rootmode;
     FXCheckButton  *trashcan;
     FXCheckButton  *trashbypass;
@@ -94,8 +96,10 @@ private:
     FXCheckButton  *del;
     FXCheckButton  *del_emptydir;
     FXCheckButton  *overwrite;
+    FXCheckButton  *exec;
     FXCheckButton  *ask;
     FXCheckButton  *bg;
+    FXCheckButton  *preserve_date_warning;
     FXCheckButton  *root_warning;
     FXCheckButton  *mount;
 	FXCheckButton  *show_mount;
@@ -120,14 +124,14 @@ private:
 	FXbool         relativeresize_prev;
 	FXbool         show_pathlink;
 	FXbool         show_pathlink_prev;
-	FXuint	       value_prev;
+	unsigned int	       value_prev;
 	FXbool		   ask_prev;
 	FXbool		   dnd_prev;
 	FXbool		   trashmv_prev;
 	FXbool		   del_prev;
 	FXbool		   del_emptydir_prev;
 	FXbool		   overwrite_prev;
-	FXbool		   quit_prev;
+	FXbool		   exec_prev;
 	FXbool		   use_clearlooks;
 	FXbool		   use_clearlooks_prev;
 	FXbool         rootmode_prev;
@@ -139,7 +143,8 @@ private:
 	FXbool		   show_mount_prev;
 #endif
 	FXbool		   root_warning_prev;
-	FXuint		   themelist_prev;
+	FXbool		   preserve_date_warning_prev;
+	unsigned int		   themelist_prev;
 	FXbool		   smoothscroll_prev;
 	KeybindingsBox 		*bindingsbox;
 	FXStringDict		*glbBindingsDict;
@@ -182,7 +187,7 @@ public:
     };
 
 public:
-    PreferencesBox(FXWindow *win,FXColor listbackcolor=FXRGB(255,255,255), FXColor listforecolor=FXRGB(0,0,0), FXColor highlightcolor=FXRGB(238,238,238),FXColor pbarcolor=FXRGB(0,0,255),FXColor attentioncolor=FXRGB(255,0,0));
+    PreferencesBox(FXWindow *win,FXColor listbackcolor=FXRGB(255,255,255), FXColor listforecolor=FXRGB(0,0,0), FXColor highlightcolor=FXRGB(238,238,238),FXColor pbarcolor=FXRGB(0,0,255),FXColor attentioncolor=FXRGB(255,0,0),FXColor scrollbackcolor=FXRGB(237,233,227));
     long onCmdAccept(FXObject*,FXSelector,void*);
     long onCmdBrowse(FXObject*,FXSelector,void*);
     long onCmdColor (FXObject*,FXSelector,void*);
@@ -198,7 +203,7 @@ public:
 	long onCmdWheelAdjust(FXObject*,FXSelector,void*);
 	long onUpdWheelAdjust(FXObject*,FXSelector,void*);
 	long onUpdSingleClickFileopen(FXObject*,FXSelector,void*);
-	FXuint execute(FXuint);
+	unsigned int execute(unsigned int);
 	long onCmdCancel(FXObject*,FXSelector,void*);
 	long onCmdControls(FXObject*,FXSelector ,void*);
 	long onUpdControls(FXObject*,FXSelector,void*);
