@@ -152,7 +152,7 @@ FXIMPLEMENT(PropertiesBox,DialogBox,PropertiesBoxMap,ARRAYNUMBER(PropertiesBoxMa
 // Construct window for one file
 PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogBox(win,_("Properties"), DECOR_TITLE|DECOR_BORDER|DECOR_STRETCHABLE)
 {
-	FXulong filesize;
+	unsigned long long filesize;
     FXString mod,changed,accessed;
 	FXString grpid, usrid;	
 	FXLabel *sizelabel=NULL;
@@ -324,7 +324,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
     accessed=FXSystem::time(timeformat.text(),linfo.st_atime);;
 
     // Size of the file / link
-    filesize=(FXulong)linfo.st_size;
+    filesize=(unsigned long long)linfo.st_size;
 
     // Is it a directory?
 	isDirectory=S_ISDIR(linfo.st_mode);
@@ -360,17 +360,30 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 			// Caution : use the -P option to be POSIX compatible!
 			snprintf(buf,sizeof(buf)-1,"df -P -B 1 '%s'",filepath.text());
 			p=popen(buf,"r");
-			fgets(buf,sizeof(buf),p);
-			fgets(buf,sizeof(buf),p);
-			strtok(buf," "); // should check if str!=NULL
-			strtok(NULL," ");// get size
-			char *pstr;
-			pstr=strtok(NULL," ");
-			strlcpy(used,pstr,strlen(pstr)+1);// get used
-			pstr=strtok(NULL," ");
-			strlcpy(avail,pstr,strlen(pstr)+1);// get available
-			pstr=strtok(NULL," ");
-			strlcpy(pctr,pstr,strlen(pstr)+1);// get percentage
+			FXbool success=TRUE;
+			if (fgets(buf,sizeof(buf),p) == NULL)
+				success=FALSE;
+			if (fgets(buf,sizeof(buf),p) == NULL)
+				success=FALSE;
+			if (success)
+			{
+				strtok(buf," ");
+				strtok(NULL," ");
+				char *pstr;
+				pstr=strtok(NULL," ");
+				strlcpy(used,pstr,strlen(pstr)+1);  // get used
+				pstr=strtok(NULL," ");
+				strlcpy(avail,pstr,strlen(pstr)+1); // get available
+				pstr=strtok(NULL," ");
+				strlcpy(pctr,pstr,strlen(pstr)+1);  // get percentage
+			}
+			else
+			{
+				strlcpy(used,"",1);
+				strlcpy(avail,"",1);
+				strlcpy(pctr,"",1);
+				
+			}
 			pclose(p);
 		}
 			
@@ -1562,7 +1575,7 @@ long PropertiesBox::onUpdSizeAndPerm(FXObject* o,FXSelector s,void* p)
 			// Directory but not mount point
 			if (isDirectory && !isMountpoint)
 			{
-				FXulong dirsize;
+				unsigned long long dirsize;
 				unsigned int nbfiles=0, nbsubfolders=0;
 
 				FXString dirpath=FXPath::absolute(parentdir,filename);
@@ -1580,10 +1593,10 @@ long PropertiesBox::onUpdSizeAndPerm(FXObject* o,FXSelector s,void* p)
 		// Multiple files
 		else
 		{
-			FXulong filesize, dirsize, totalsize=0;
+			unsigned long long filesize, dirsize, totalsize=0;
 			unsigned int totalnbfiles=0, totalnbsubfolders=0;
 			struct stat info;
-			int dotdot=0;
+			//int dotdot=0;
 
 			// Total size and files type
 			for (int i=0;i<num;i++)
@@ -1594,7 +1607,7 @@ long PropertiesBox::onUpdSizeAndPerm(FXObject* o,FXSelector s,void* p)
 				// Special case of the ".." directory
 				if (files[i]=="..")
 				{	
-					dotdot=1;
+					//dotdot=1;
 					continue;
 				}
 
