@@ -577,7 +577,12 @@ long ViewWindow::onCmdPrint(FXObject*,FXSelector,void*)
 	
 	// Perform the print command
 	command =  "cat " + filename + " |" + printcommand + " &";
-	system(command.text());
+	int ret=system(command.text());
+	if (ret < 0)
+	{
+		MessageBox::error(this,BOX_OK,_("Error"),_("Can't execute command %s"),command.text());
+		return 0;
+	}
 	
     return 1;
 }
