@@ -31,10 +31,10 @@ protected:
 	FXTextField			*findtext;
 	FXbool				smoothscroll;
 	FXbool 				fromreg;			// Read window size and position from the regsitry
-	FXuint 				ww;			        // Window width
-	FXuint 				hh;					// Window height
-	FXuint 				xx;					// Window x position 
-	FXuint 				yy;					// Window y position
+	unsigned int 				ww;			        // Window width
+	unsigned int 				hh;					// Window height
+	unsigned int 				xx;					// Window x position 
+	unsigned int 				yy;					// Window y position
 	FXString			searchstr;
 private:
     ViewWindow()
@@ -163,7 +163,7 @@ public:
     virtual FXbool close(FXbool notify=FALSE);
     FXbool loadFile(const FXString& file);
 	void saveConfig();
-    FXint find(const FXString,FXint);
+    int find(const FXString,int);
 };
 
 typedef FXObjectListOf<ViewWindow> ViewWindowList;
