@@ -519,7 +519,7 @@ XFileImage::XFileImage(FXApp* a, FXbool smoothscroll):FXMainWindow(a,"Xfi ",NULL
 
     // View Menu entries
  	key=getApp()->reg().readStringEntry("KEYBINDINGS","hidden_files","Ctrl-F6");
-	text=_("&Hidden files")+TABS(key)+_("Show hidden files and directories.")+PARS(key);
+	text=_("&Hidden files")+TABS(key)+_("Show hidden files and folders.")+PARS(key);
     mc=new FXMenuCheck(viewmenu,text,this,ID_TOGGLE_HIDDEN);
 	hotkey=_parseAccel(key);
 	getAccelTable()->addAccel(hotkey,mc,FXSEL(SEL_COMMAND,FXMenuCommand::ID_ACCEL));
@@ -654,7 +654,7 @@ long XFileImage::onCmdPopupMenu(FXObject* o,FXSelector s,void* p)
 	new FXMenuRadio(&menu,_("&Permissions"),filelist,FileList::ID_SORT_BY_PERM);
 	new FXMenuSeparator(&menu);
 	new FXMenuCheck(&menu,_("Ignore c&ase"),filelist,FileList::ID_SORT_CASE);
-	new FXMenuCheck(&menu,_("Dir&ectories first"),filelist,FileList::ID_DIRS_FIRST);
+	new FXMenuCheck(&menu,_("Fold&ers first"),filelist,FileList::ID_DIRS_FIRST);
 	new FXMenuCheck(&menu,_("Re&verse order"),filelist,FileList::ID_SORT_REVERSE);
 
 	menu.create();
@@ -1242,7 +1242,12 @@ long XFileImage::onCmdPrint(FXObject*,FXSelector,void*)
 	
 	// Perform the print command
 	command =  "cat " + filename + " |" + printcommand + " &";
-	system(command.text());
+	int ret=system(command.text());
+	if (ret < 0)
+	{
+		MessageBox::error(this,BOX_OK,_("Error"),_("Can't execute command %s"),command.text());
+		return 0;
+	}
 	
     return 1;
 }
