@@ -11,6 +11,7 @@
 #include <unistd.h>
 #include <sys/stat.h>
 #include <sys/wait.h>
+#include <sys/signal.h>
 
 #include "xfedefs.h"
 #include "icons.h"
@@ -25,10 +26,6 @@
 // Add FOX hacks
 #include "foxhacks.cpp"
 
-// Maximum length of a file name
-#ifndef MAXPATHLEN
-#define MAXPATHLEN 1024
-#endif
 
 char **args;
 FXbool dpkg=FALSE;
