@@ -9,8 +9,8 @@
 \n \
                                   XFE, X File Explorer File Manager\n \
 \n \
-                                    <http://roland65.free.fr/xfe>\n \
-                                <http://sourceforge.net/projects/xfe>\n \
+                                    <http://roland65.free.fr/Xfe>\n \
+                                <http://sourceforge.net/projects/Xfe>\n \
 \n \
 \n \
 \n \
@@ -31,7 +31,7 @@
   Description\n \
   =-=-=-=-=-=\n \
 \n \
- X File Explorer (xfe) is a lightweight file manager for X11, written using the FOX toolkit.\n \
+ X File Explorer (Xfe) is a lightweight file manager for X11, written using the FOX toolkit.\n \
  It is desktop independent and can easily be customized.\n \
  It has Commander or Explorer styles and it is very fast and small.\n \
  Xfe is based on the popular, but discontinued X Win Commander, originally written by Maxim Baranov.\n \
@@ -43,13 +43,14 @@
 \n \
     - Very fast graphic user interface\n \
     - UTF-8 support\n \
-    - Commander/Explorer interface with four file manager modes : a) one panel, b) a directory tree\n \
-      and one panel, c) two panels and d) a directory tree and two panels\n \
+    - Commander/Explorer interface with four file manager modes : a) one panel, b) a folder tree\n \
+      and one panel, c) two panels and d) a folder tree and two panels\n \
     - Panels synchronization and switching\n \
     - Integrated text editor (X File Write, xfw)\n \
     - Integrated text viewer (X File View, xfv)\n \
     - Integrated image viewer (X File Image, xfi)\n \
     - Integrated package (rpm or deb) viewer / installer / uninstaller (X File Package, xfp)\n \
+    - Custom shell scripts (like Nautilus scripts)\n \
     - Copy/Cut/Paste files from and to your favorite desktop (GNOME/KDE/XFCE/ROX)\n \
     - Drag and Drop files from and to your favorite desktop (GNOME/KDE/XFCE/ROX)\n \
     - Root mode with authentication by su or sudo\n \
@@ -57,14 +58,14 @@
     - File associations\n \
     - Optional trash can for file delete operations (compliant with freedesktop.org standards)\n \
     - Auto save registry\n \
-    - Double click or single click files and directories navigation\n \
+    - Double click or single click file and folder navigation\n \
     - Mouse right click pop-up menu in tree list and file list\n \
     - Change file attributes\n \
     - Mount/Unmount devices (Linux only)\n \
     - Warn when mount point are not responding (Linux only)\n \
     - Toolbars\n \
     - Bookmarks\n \
-    - Back and forward history lists for directory navigation\n \
+    - Back and forward history lists for folder navigation\n \
     - Color themes (GNOME, KDE, Windows...)\n \
     - Icon themes (Xfe, GNOME, KDE, XFCE, Tango, Windows...)\n \
     - Control themes (Standard or Clearlooks like)\n \
@@ -89,7 +90,7 @@
     * Search                             - Ctrl-F\n \
     * Search previous                    - Shift-Ctrl-G\n \
     * Search next                        - Ctrl-G\n \
-    * Go to home directory               - Ctrl-H\n \
+    * Go to home folder                  - Ctrl-H\n \
     * Invert selection                   - Ctrl-I\n \
     * Open file                          - Ctrl-O\n \
     * Print file                         - Ctrl-P\n \
@@ -99,29 +100,29 @@
     * Cut to clipboard                   - Ctrl-X\n \
     * Deselect all                       - Ctrl-Z\n \
     * Display help                       - F1\n \
-    * Create new file                    - F2\n \
+    * Create new file                    - Ctrl-N\n \
     * Create new folder                  - F7\n \
     * Big icon list                      - F10\n \
     * Small icon list                    - F11\n \
     * Detailed file list                 - F12\n \
     * Toggle display hidden files        - Ctrl-F6\n \
     * Toggle display thumbnails          - Ctrl-F7\n \
-    * Go to working directory            - Shift-F2\n \
-    * Go to parent directory             - Backspace\n \
-    * Go to previous directory           - Ctrl-Backspace\n \
-    * Go to next directory               - Shift-Backspace\n \
+    * Go to working folder               - Shift-F2\n \
+    * Go to parent folder                - Backspace\n \
+    * Go to previous folder              - Ctrl-Backspace\n \
+    * Go to next folder                  - Shift-Backspace\n \
 \n \
 \n \
- Below are the default X File Explorer key bindings. These key bindings are specific to the xfe application.\n \
+ Below are the default X File Explorer key bindings. These key bindings are specific to the Xfe application.\n \
 \n \
     * Add bookmark                      - Ctrl-B\n \
-    * Filter files                      - ctrl-D\n \
+    * Filter files                      - Ctrl-D\n \
     * Execute command                   - Ctrl-E\n \
     * Create new symbolic link          - Ctrl-J\n \
     * Switch panels                     - Ctrl-K\n \
     * Clear location bar                - Ctrl-L\n \
     * Mount file system (Linux only)    - Ctrl-M\n \
-    * Rename file                       - Ctrl-N\n \
+    * Rename file                       - F2\n \
     * Refresh panels                    - Ctrl-R\n \
     * Symlink files to location         - Ctrl-S\n \
     * Launch terminal                   - Ctrl-T\n \
@@ -136,7 +137,7 @@
     * Tree and panel mode               - Ctrl-F2\n \
     * Two panels mode                   - Ctrl-F3\n \
     * Tree and two panels mode          - Ctrl-F4\n \
-    * Toggle display hidden directories - Ctrl-F5\n \
+    * Toggle display hidden folders     - Ctrl-F5\n \
     * Go to trash can                   - Ctrl-F8\n \
     * Create new root window            - Shift-F3\n \
     * View                              - Shift-F4\n \
@@ -172,13 +173,13 @@
 \n \
  X File View (xfv) and X File Package (xfp) only use some of the global key bindings.\n \
 \n \
- Note that all the default key bindings listed above can be customized in the xfe Preferences dialog. However,\n \
+ Note that all the default key bindings listed above can be customized in the Xfe Preferences dialog. However,\n \
  some key actions are hardcoded an cannot be changed. These include:\n \
 \n \
     * Ctrl-+ and Ctrl--                 - zoom in and zoom out image in xfi\n \
-    * Shift-F10                         - display context menus in xfe\n \
-    * Return                            - enter directories in file lists, open files, select button actions, etc.\n \
-    * Space                             - enter directories in file lists\n \
+    * Shift-F10                         - display context menus in Xfe\n \
+    * Return                            - enter folders in file lists, open files, select button actions, etc.\n \
+    * Space                             - enter folders in file lists\n \
     * Esc                               - close current dialog, unselect files, etc.\n \
 \n \
 \n \
@@ -187,7 +188,7 @@
   =-=-=-=-=-=-=-=-=-=-=-=-=\n \
 \n \
  Dragging a file or group or files (by moving the mouse while maintaining the left button pressed)\n \
- to a directory or a file panel optionally opens a dialog that allows one to select the file operation: copy,\n \
+ to a folder or a file panel optionally opens a dialog that allows one to select the file operation: copy,\n \
  move, link or cancel.\n \
 \n \
 \n \
@@ -195,8 +196,8 @@
   Trash system\n \
   =-=-=-=-=-=-=\n \
 \n \
- Starting with version 1.32, xfe implements a trash system that is fully compliant with the freedesktop.org standards.\n \
- This allows the user to move files to the trash can and to restore files from within xfe or your favorite\n \
+ Starting with version 1.32, Xfe implements a trash system that is fully compliant with the freedesktop.org standards.\n \
+ This allows the user to move files to the trash can and to restore files from within Xfe or your favorite\n \
  desktop.\n \
  Note that the trash files location is now: ~/.local/share/Trash/files\n \
 \n \
@@ -205,31 +206,66 @@
   Configuration\n \
   =-=-=-=-=-=-=\n \
 \n \
- You can perform any xfe customization (layout, file associations, key bindings, etc.) without editing any file\n \
+ You can perform any Xfe customization (layout, file associations, key bindings, etc.) without editing any file\n \
  by hand. However, you may want to understand the configuration principles, because some customizations can also\n \
  easily be done by manually editing the configurations files.\n \
- Be careful to quit xfe before manually editing any configuration file, otherwise changes could not be taken\n \
+ Be careful to quit Xfe before manually editing any configuration file, otherwise changes could not be taken\n \
  into account.\n \
 \n \
- The system-wide configuration file xferc is located in /usr/share/xfe, /usr/local/share/xfe\n \
- or /opt/local/share/xfe, in the given order of precedence.\n \
+ The system-wide configuration file Xferc is located in /usr/share/Xfe, /usr/local/share/Xfe\n \
+ or /opt/local/share/Xfe, in the given order of precedence.\n \
 \n \
  Starting with version 1.32, the location of the local configuration files has changed. This is to be compliant\n \
  with the freedesktop.org standards.\n \
  \n \
- The local configuration files for xfe, xfw, xfv, xfi, xfp are now located in the ~/.config/xfe directory.\n \
- They are named xferc, xfwrc, xfvrc, xfirc and xfprc.\n \
+ The local configuration files for Xfe, xfw, xfv, xfi, xfp are now located in the ~/.config/Xfe folder.\n \
+ They are named Xferc, xfwrc, xfvrc, xfirc and xfprc.\n \
  \n \
- At the very first xfe run, the system-wide configuration file is copied into the local configuration file\n \
- ~/.config/xfe/xferc which does not exists yet. If the system-wide configuration file is not found\n \
+ At the very first Xfe run, the system-wide configuration file is copied into the local configuration file\n \
+ ~/.config/Xfe/Xferc which does not exists yet. If the system-wide configuration file is not found\n \
  (in case of an unusal install place), a dialog asks the user to select the right place. It is thus easier to\n \
- customize xfe (this is particularly true for the file associations) by hand editing because all the local options are\n \
+ customize Xfe (this is particularly true for the file associations) by hand editing because all the local options are\n \
  located in the same file.\n \
 \n \
- Default PNG icons are located in /usr/share/xfe/icons/xfe-theme or /usr/local/share/xfe/icons/xfe-theme, depending\n \
+ Default PNG icons are located in /usr/share/Xfe/icons/Xfe-theme or /usr/local/share/Xfe/icons/Xfe-theme, depending\n \
  on your installation. You can easily change the icon theme path in Preferences dialog.\n \
 \n \
 \n \
+\n \
+  Scripts\n \
+  =-=-=-=\n \
+\n \
+ Custom shell scripts can be executed from within Xfe on the files that are selected in a panel. You have to first\n \
+ select the files you want to proceed, then right click on the file list and go to the Scripts sub menu. Last, choose\n \
+ the script you want to apply on the selected files.\n \
+\n \
+ The script files must be located in the ~/.config/Xfe/scripts folder and have to be executable. You can organize\n \
+ this folder as you like by using sub-folders. You can use the Tools / Go to script folder menu item to directly go\n \
+ to the script folder and manage it.\n \
+\n \
+ Here is an example of a simple shell script that list each selected file on the terminal from where Xfe was launched:\n \
+\n \
+ #!/bin/sh\n \
+ for arg\n \
+ do\n \
+ /bin/ls -la \"$arg\"\n \
+ done\n \
+\n \
+ You can of course use programs like xmessage, zenity or kdialog to display a window with buttons that allows you to\n \
+ interact with the script. Here is a modification of the above example that uses xmessage:\n \
+\n \
+ #!/bin/sh\n \
+ (\n \
+ echo  \"ls -la\"\n \
+ for arg\n \
+ do\n \
+ /bin/ls -la \"$arg\"\n \
+ done\n \
+ ) | xmessage -file -\n \
+\n \
+ Most often, it is possible to directly use Nautilus scripts found on the Internet without modifications.\n \
+\n \
+\n \
 \n \
   Non Latin based languages\n \
   =-=-=-=-=-=-=-=-=-=-=-=-=\n \
@@ -275,7 +311,7 @@
   Bugs\n \
   =-=-=\n \
 \n \
- Please report any found bug to Roland Baudin <roland65@free.fr>. Don't forget to mention the xfe version you use,\n \
+ Please report any found bug to Roland Baudin <roland65@free.fr>. Don't forget to mention the Xfe version you use,\n \
  the FOX library version and your system name and version.\n \
 \n \
 \n \
@@ -283,10 +319,10 @@
   Translations\n \
   =-=-=-=-=-=-=\n \
  \n \
- xfe is now available in 19 languages but some translations are only partial. To translate xfe to your language,\n \
- open the xfe.pot file located in the po directory of the source tree with a software like poedit, kbabel\n \
+ Xfe is now available in 19 languages but some translations are only partial. To translate Xfe to your language,\n \
+ open the Xfe.pot file located in the po folder of the source tree with a software like poedit, kbabel\n \
  or gtranslator and fill it with your translated strings (be careful to the hotkeys and c-format characters),\n \
- and then send it back to me. I'll be pleased to integrate your work in the next xfe release.\n \
+ and then send it back to me. I'll be pleased to integrate your work in the next Xfe release.\n \
 \n \
 \n \
 \n \
@@ -299,7 +335,7 @@
  Many thanks to Maxim Baranov for his excellent X Win Commander and to all people that have provided useful\n \
  patches, translations, tests and advices.\n \
 \n \
- [Last revision: 6/04/2012]\n \
+ [Last revision: 21/08/2013]\n \
 \n \
  ")
 ;
