@@ -72,8 +72,20 @@ Time gettimestamp (void)
 // Launch a command and initiate a startup notification 
 int runcmd(FXString cmd, FXString cmdname, FXString dir, FXString startdir, FXbool usesn=TRUE, FXString snexcepts="")
 {
+	int ret;
+	
 	// Change to current directory
-	chdir(dir.text());
+	ret=chdir(dir.text());
+	if (ret < 0)
+	{
+		int errcode=errno;	
+		if (errcode)
+			fprintf(stderr,_("Error: Can't enter folder %s: %s"),dir.text(),strerror(errcode));
+		else
+			fprintf(stderr,_("Error: Can't enter folder %s"),dir.text());
+		
+		return -1;
+	}
 	
 	// Get rid of possible command options
 	cmdname=cmdname.before(' ');
@@ -108,8 +120,16 @@ int runcmd(FXString cmd, FXString cmdname, FXString dir, FXString startdir, FXbo
 		xdisplay = XOpenDisplay(NULL);
 		if (xdisplay == NULL)
 		{
-			fprintf (stderr,_("Error! Can't open display\n"));
-			chdir(startdir.text());
+			fprintf (stderr,_("Error: Can't open display\n"));
+			ret=chdir(startdir.text());
+			if (ret < 0)
+			{
+				int errcode=errno;	
+				if (errcode)
+					fprintf(stderr,_("Error: Can't enter folder %s: %s"),startdir.text(),strerror(errcode));
+				else
+					fprintf(stderr,_("Error: Can't enter folder %s"),startdir.text());
+			}
 			return -1;
 		}
 	  
@@ -134,7 +154,7 @@ int runcmd(FXString cmd, FXString cmdname, FXString dir, FXString startdir, FXbo
 		switch ((child_pid = fork ()))
 		{
 			case -1:
-				fprintf (stderr,_("Error! Fork failed: %s\n"),strerror (errno));
+				fprintf (stderr,_("Error: Fork failed: %s\n"),strerror (errno));
 				break;
 		
 			case 0:
@@ -151,15 +171,30 @@ int runcmd(FXString cmd, FXString cmdname, FXString dir, FXString startdir, FXbo
 	{
 		// Run command in background
 		cmd += " &";
-		system(cmd.text());
+		ret=system(cmd.text());
+		if (ret < 0)
+		{
+			fprintf(stderr,_("Error: Can't execute command %s"),cmd.text());		
+			return -1;
+		}
 	
 		// Just display the wait cursor during a second
 		sleep(1);
 	}
 	
 	// Go back to startup directory
-	chdir(startdir.text());
-	
+	ret=chdir(startdir.text());
+	if (ret < 0)
+	{
+		int errcode=errno;	
+		if (errcode)
+			fprintf(stderr,_("Error: Can't enter folder %s: %s"),startdir.text(),strerror(errcode));
+		else
+			fprintf(stderr,_("Error: Can't enter folder %s"),startdir.text());
+		
+		return -1;
+	}
+
 	return 0;
 }
 
@@ -169,18 +204,45 @@ int runcmd(FXString cmd, FXString cmdname, FXString dir, FXString startdir, FXbo
 // Run a command and simulate a startup time
 int runcmd(FXString cmd, FXString dir, FXString startdir)
 {
+	int ret;
+	
 	// Change to current directory
-	chdir(dir.text());
+	ret=chdir(dir.text());
+	if (ret < 0)
+	{
+		int errcode=errno;	
+		if (errcode)
+			fprintf(stderr,_("Error: Can't enter folder %s: %s"),dir.text(),strerror(errcode));
+		else
+			fprintf(stderr,_("Error: Can't enter folder %s"),dir.text());
+		
+		return -1;
+	}
 
 	// Run the command in background
 	cmd += " &";
-	system(cmd.text());
+	ret=system(cmd.text());
+	if (ret < 0)
+	{
+		fprintf(stderr,_("Error: Can't execute command %s"),cmd.text());		
+		return -1;
+	}
 	
 	// Very ugly simulation of a startup time!!!
 	sleep(SIMULATED_STARTUP_TIME);
 	
 	// Go back to startup directory
-	chdir(startdir.text());
+	ret=chdir(startdir.text());
+	if (ret < 0)
+	{
+		int errcode=errno;	
+		if (errcode)
+			fprintf(stderr,_("Error: Can't enter folder %s: %s"),startdir.text(),strerror(errcode));
+		else
+			fprintf(stderr,_("Error: Can't enter folder %s"),startdir.text());
+		
+		return -1;
+	}
 
 	return 0;
 }
