@@ -22,6 +22,7 @@
 
 
 
+
 // Note : the original function from FXAccelTable is buggy!!
 // Parse accelerator from string
 FXHotKey _parseAccel(const FXString& string)
@@ -195,7 +196,7 @@ FXbool existCommand(const FXString cmd)
 // Get key binding string from user input
 // Code adapted from FXAccelTable::unparseAccel() and modified to get strings like 'Ctrl-A' instead of 'ctrl+a'
 FXString getKeybinding(FXEvent* event)
-{
+{	
 	// Get modifiers and key
 	int mods=event->state;
 	int code=event->code;
@@ -296,7 +297,7 @@ FXString getKeybinding(FXEvent* event)
 		case KEY_F33:
 		case KEY_F34:
 		case KEY_F35:
-			sprintf(buffer,"F%d",code-KEY_F1+1);			
+			snprintf(buffer,sizeof(buffer)-1,"F%d",code-KEY_F1+1);			
 			s+=buffer;
 			break;
 		default:
@@ -306,6 +307,7 @@ FXString getKeybinding(FXEvent* event)
 			s="";  // Invalid case
 		break;
 	}
+
 	return s;
 }
 
@@ -610,7 +612,7 @@ FXulong dirsize(const char* path)
 		}
 	}
 	if(closedir(dp)<0)
-        fprintf(stderr,_("Can't close folder %s\n"), path);
+        fprintf(stderr,_("Error: Can't close folder %s\n"), path);
 	return dsize;
 }
 
@@ -665,7 +667,7 @@ FXulong pathsize(char* path, unsigned int* nbfiles, unsigned int* nbsubdirs)
     ptr[-1]='\0'; // ??
 	
     if(closedir(dp)<0)
-        fprintf(stderr,_("Can't close folder %s\n"), path);
+        fprintf(stderr,_("Error: Can't close folder %s\n"), path);
     return dsize;
 }
 
@@ -678,7 +680,7 @@ FXString hSize(char* size)
 	char buf[128];
 	FXString hsize;
 
-    FXulong lsize = strtoull(size,NULL,10);
+    unsigned long long lsize = strtoull(size,NULL,10);
     float fsize=0.0;
 
 	strlcpy(suf,_("bytes"),sizeof(suf)); 
@@ -947,13 +949,24 @@ FXbool isGroupMember(gid_t gid)
 	static int ngroups = 0;
 	static gid_t *gids = NULL;
 	int i;
+	int ret;
 
 	// First call : initialization of the number of supplementary groups and the group list
 	if (ngroups == 0)
 	{
 		ngroups = getgroups(0, gids);
 		gids = new gid_t[ngroups];
-		getgroups(ngroups, gids);
+		ret = getgroups(ngroups, gids);
+		if (ret < 0)
+		{
+			int errcode=errno;	
+			if (errcode)
+				fprintf(stderr,_("Error: Can't read group list: %s"),strerror(errcode));
+			else
+				fprintf(stderr,_("Error: Can't read group list"));
+			
+			return FALSE;
+		}
 	}
 	if (ngroups == 0)
 		return FALSE;
@@ -1215,7 +1228,7 @@ int runinxvt(FXString cmd)
     // Fork failed
     else
     {
-		fprintf (stderr,_("Error! Fork failed: %s\n"),strerror (errno));
+		fprintf (stderr,_("Error: Fork failed: %s\n"),strerror (errno));
 		res=-1;
     }
 	
@@ -1226,5 +1239,3 @@ int runinxvt(FXString cmd)
 	
 	return res;
 }
-
-
