@@ -36,7 +36,12 @@
 #include <unistd.h>
 #include <signal.h>
 #include <fcntl.h>
-#include <utmp.h>
+#include <sys/param.h>
+#if __FreeBSD_version >= 900007
+#    include <utmpx.h>
+#else
+#    include <utmp.h>
+#endif
 #include <errno.h>
 #include <string.h>
 #include "xvt.h"
@@ -251,7 +256,7 @@ static struct keymapst kp_key_table[]=
 
 static void push_xevent(struct xeventst *);
 static struct xeventst *pop_xevent(void);
-static unsigned char * get_keycode_value(struct keymapst *,KeySym,unsigned char *,int);
+static unsigned char * get_keycode_value(struct keymapst *,KeySym,unsigned char *,size_t, int);
 static unsigned char *lookup_key(XEvent *,int *);
 static int get_com_char(int);
 static void push_com_char(int);
@@ -332,7 +337,7 @@ void set_sun_function_keys(int value)
 
 /*  Look up function key keycode
 */
-static unsigned char * get_keycode_value(struct keymapst* keymaptable, KeySym keysym, unsigned char* buf, int use_alternate)
+static unsigned char * get_keycode_value(struct keymapst* keymaptable, KeySym keysym, unsigned char* buf, size_t bufsize, int use_alternate)
 {
     struct keymapst *km;
     struct keystringst *ks;
@@ -347,22 +352,22 @@ static unsigned char * get_keycode_value(struct keymapst* keymaptable, KeySym ke
             case KS_TYPE_NONE:
                 return NULL;
             case KS_TYPE_CHAR:
-                sprintf((char *)buf,"%c",ks->ks_value);
+                snprintf((char *)buf,bufsize,"%c",ks->ks_value);
                 return buf;
             case KS_TYPE_XTERM:
-                sprintf((char *)buf,"\033[%d~",ks->ks_value);
+                snprintf((char *)buf,bufsize,"\033[%d~",ks->ks_value);
                 return buf;
             case KS_TYPE_SUN:
-                sprintf((char *)buf,"\033[%dz",ks->ks_value);
+                snprintf((char *)buf,bufsize,"\033[%dz",ks->ks_value);
                 return buf;
             case KS_TYPE_APPKEY:
-                sprintf((char *)buf,"\033O%c",ks->ks_value);
+                snprintf((char *)buf,bufsize,"\033O%c",ks->ks_value);
                 return buf;
             case KS_TYPE_NONAPP:
-                sprintf((char *)buf,"\033[%c",ks->ks_value);
+                snprintf((char *)buf,bufsize,"\033[%c",ks->ks_value);
                 return buf;
             case KS_TYPE_VT220:
-                sprintf((char *)buf,"\033[%d~",ks->ks_value);
+                snprintf((char *)buf,bufsize,"\033[%d~",ks->ks_value);
                 return buf;
             }
         }
@@ -386,11 +391,11 @@ static unsigned char *lookup_key(XEvent* ev, int* pcount)
     if (IsFunctionKey(keysym) || IsMiscFunctionKey(keysym)
             || keysym == XK_Next || keysym == XK_Prior
             || keysym == XK_Delete || keysym == XK_BackSpace)
-        s = get_keycode_value(func_key_table,keysym,kbuf,sun_function_keys);
+        s = get_keycode_value(func_key_table,keysym,kbuf,KBUFSIZE,sun_function_keys);
     else if (IsCursorKey(keysym) || IsPFKey(keysym))
-        s = get_keycode_value(other_key_table,keysym,kbuf,app_cur_keys);
+        s = get_keycode_value(other_key_table,keysym,kbuf,KBUFSIZE,app_cur_keys);
     else
-        s = get_keycode_value(kp_key_table,keysym,kbuf,app_kp_keys);
+        s = get_keycode_value(kp_key_table,keysym,kbuf,KBUFSIZE,app_kp_keys);
 
     if (s != NULL)
     {
@@ -651,7 +656,7 @@ void cprintf(char *fmt,...)
     static unsigned char buf[1024];
 
     va_start(args,fmt);
-    vsprintf((char *)buf,fmt,args);
+    vsnprintf((char *)buf,sizeof(buf)-1,fmt,args);
     va_end(args);
     send_string(buf,strlen((char *)buf));
 }
