@@ -1170,7 +1170,6 @@ void scr_make_selection(int time)
 void scr_send_selection(int time, int requestor, int target, int property)
 {
     XEvent event;
-    int status;
 
     event.xselection.type = SelectionNotify;
     event.xselection.selection = XA_PRIMARY;
@@ -1185,7 +1184,7 @@ void scr_send_selection(int time, int requestor, int target, int property)
     }
     else
         event.xselection.property = None;
-    status = XSendEvent(display,requestor,False,0,&event);
+    XSendEvent(display,requestor,False,0,&event);
 }
 
 /*  Request the current primary selection
@@ -2106,7 +2105,7 @@ static void selend_to_rc(int* rowp, int* colp, struct selst* se)
  */
 static void change_selection(struct selst* ose1, struct selst* ose2)
 {
-    int rs, cs, re, ce, n;
+    int rs=0, cs=0, re=0, ce=0, n;
     int row;
     int row1, row2;
     int x1, x2, y;
