@@ -38,6 +38,12 @@
 #include <signal.h>
 #include <fcntl.h>
 #include <utmp.h>
+#include <sys/param.h>
+#if __FreeBSD_version >= 900007
+#    include <utmpx.h>
+#else
+#    include <utmp.h>
+#endif
 #include <grp.h>
 #include <pwd.h>
 #include <errno.h>
@@ -134,7 +140,7 @@
 #endif /* LINUX */
 
 /* GNU KFREEBSD */
-#if defined (__FreeBSD_kernel__)
+#if defined (__FreeBSD_kernel__) && !defined (__FreeBSD__)
 #include <sys/ioctl.h>
 #include <pty.h>
 #define BSD_PTY
@@ -175,7 +181,9 @@ static char *tty_name = NULL;	/* name of the slave teletype */
 #ifdef BSD_UTMP
 static int tslot = -1;		/* index to our slot in the utmp file */
 #endif /* BSD_UTMP */
+#if defined(BSD_UTMP) || defined(SVR4_UTMP)
 static struct utmp utent;	/* our current utmp entry */
+#endif
 
 /*  Catch a SIGCHLD signal and exit if the direct child has died.
  */
@@ -231,8 +239,8 @@ static void write_utmp()
         error("Can's parse tty name %s",tty_name);
         return;
     }
-    sprintf(utentx.ut_id,"vt%02x",n);
-    sprintf(utentx.ut_line,"pts/%d",n);
+    snprintf(utentx.ut_id,sizeof(utentx.ut_id)-1,"vt%02x",n);
+    snprintf(utentx.ut_line,sizeof(utentx.ut_line)-1,"pts/%d",n);
     pw = getpwuid(getuid());
     if (pw != NULL)
         strncpy(utentx.ut_name,pw->pw_name,sizeof(utent.ut_name));
@@ -385,8 +393,9 @@ static int get_tslot(char* ttynam)
  */
 static char* get_pseudo_tty(int* pmaster, int* pslave)
 {
-#ifdef BSD_PTY
-    int mfd, sfd;
+    int mfd = 0, sfd = 0;
+    char *ttynam = NULL;
+#if defined(BSD_PTY) || defined(__FreeBSD__)
     char *s3, *s4;
     static char ptyc3[] = "pqrstuvwxyz";
     static char ptyc4[] = "0123456789abcdef";
@@ -429,8 +438,6 @@ static char* get_pseudo_tty(int* pmaster, int* pslave)
 #endif /* BSD_PTY */
 
 #ifdef SVR4_PTY
-    char *ttynam;
-    int mfd, sfd;
 
     if ((mfd = open("/dev/ptmx",O_RDWR)) < 0)
     {
@@ -450,8 +457,6 @@ static char* get_pseudo_tty(int* pmaster, int* pslave)
 #endif /* SVR4_PTY */
 
 #ifdef LIBC_OPENPTY
-    char *ttynam;
-    int mfd, sfd;
 
     if (openpty(&mfd, &sfd, NULL, NULL, NULL))
     {
@@ -630,14 +635,22 @@ int run_command(char* command, char** argv)
             gid = gr->gr_gid;
         else
             gid = -1;
-        fchown(ttyfd,uid,gid);
+        
+        if (fchown(ttyfd,uid,gid) < 0)
+        	error("failed to chown ttyfd\n");
         fchmod(ttyfd,messages ? 0620 : 0600);
+        
         for (i = 0; i < fd_width; i++)
             if (i != ttyfd)
                 close(i);
-        dup(ttyfd);
-        dup(ttyfd);
-        dup(ttyfd);
+
+        if (dup(ttyfd) < 0)
+        	error("failed to dup ttyfd\n");
+        if (dup(ttyfd) < 0)
+        	error("failed to dup ttyfd\n");
+        if (dup(ttyfd) < 0)
+        	error("failed to dup ttyfd\n");
+
         if (ttyfd > 2)
             close(ttyfd);
 #ifdef BSD_TTY
